      PROGRAM demo_netcdf
      IMPLICIT none
c======================================================================
c Programme demonstrating how to write a 2-D or 3-D variables in NetCDF
c
c pgf90 demo_netcdf_writing.F -L/distrib/local/netcdf/pgf/lib -lnetcdf
c g95 demo_netcdf_writing.F -I$HOME/netcdf/include -L$HOME/netcdf/lib -lnetcdf
c======================================================================
      INTEGER iim, jjm, klev, mois
      PARAMETER (iim=36, jjm=25, klev=19, mois=12)
c======================================================================
c
      REAL x(iim), y(jjm), z(klev)
      REAL mask(iim,jjm)
c
      REAL tsol(iim,jjm,mois)
      REAL temp(iim,jjm,klev,mois)
c
      INTEGER i, k, j, m
c
      DO i = 1, iim
         x(i) = FLOAT(i)
      ENDDO
      DO j = 1, jjm
         y(j) = FLOAT(j)
      ENDDO
      DO k = 1, klev
         z(k) = FLOAT(k)
      ENDDO
c
      mask = 1.0
      tsol=12.0
      temp = 12.0
c
      CALL ecrit_netcdf2d("fichier2d.nc",iim,jjm,
     .                  x,y,mask,1.0e+30,mois,tsol)
c
c
      CALL ecrit_netcdf3d("fichier3d.nc",iim,jjm,klev,x,y,z,
     .                    mask,1.0e+30,mois,temp)
c
      STOP
      END
      SUBROUTINE ecrit_netcdf2d(ficnom,iim,jjm,x,y,mask,missing,nb,vari)
      IMPLICIT none
c
      CHARACTER*(*) ficnom
      INTEGER iim, jjm, nb
      REAL x(iim), y(jjm), mask(iim,jjm)
      REAL vari(iim,jjm,nb)
      REAL missing
c
#include "netcdf.inc"
c
      INTEGER ierr, mid, varid
      INTEGER idim_x, idim_y, idim_t
      INTEGER dims2(2), dims3(3)
c
      INTEGER id_time, id_vari, n
c
      INTEGER debu3(3), epai3(3)
c
c Ouvrir le fichier a ecrire:
c
      ierr = NF_CREATE(ficnom, NF_CLOBBER, mid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme d ouverture du fichier:"//ficnom
         CALL abort
      ENDIF
c
c Preciser quelques attributs globaux:
c
      ierr = NF_PUT_ATT_TEXT (mid, NF_GLOBAL, "title", 29,
     .                       "Ecriture rapide d un champ 2D")
      ierr = NF_PUT_ATT_TEXT (mid, NF_GLOBAL, "model", 33,
     .                       "Resultats issus d un diagnostique")
c
c Definir les dimensions du fichier:
c
      ierr = NF_DEF_DIM(mid,"x",iim,idim_x)
      ierr = NF_DEF_DIM(mid,"y",jjm,idim_y)
      ierr = NF_DEF_DIM(mid, "time", NF_UNLIMITED, idim_t)
c
      ierr = NF_ENDDEF(mid) ! sortir du mode de definition
c
c Definir et enregistrer certains champs invariants:
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"x",NF_FLOAT,1,idim_x,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir x"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "long_name", 10,"Longitudes")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "short_name", 1,"x")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 12,"degrees_east")
      ierr = NF_ENDDEF(mid)
#ifdef NC_DOUBLE
      ierr = NF_PUT_VAR_DOUBLE(mid,varid,x)
#else
      ierr = NF_PUT_VAR_REAL(mid,varid,x)
#endif
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer x"
         CALL abort
      ENDIF
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"y",NF_FLOAT,1,idim_y,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir y"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "long_name", 9,"Latitudes")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "short_name", 1,"y")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 13,"degrees_north")
      ierr = NF_ENDDEF(mid)
#ifdef NC_DOUBLE
      ierr = NF_PUT_VAR_DOUBLE(mid,varid,y)
#else
      ierr = NF_PUT_VAR_REAL(mid,varid,y)
#endif
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer y"
         CALL abort
      ENDIF
c
      dims2(1) = idim_x
      dims2(2) = idim_y
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"mask",NF_FLOAT,2,dims2,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir mask"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid,varid,"long_name",6,"Masque")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "short_name", 4,"mask")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 1,"-")
      ierr = NF_ENDDEF(mid)
#ifdef NC_DOUBLE
      ierr = NF_PUT_VAR_DOUBLE(mid,varid,mask)
#else
      ierr = NF_PUT_VAR_REAL(mid,varid,mask)
#endif
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer mask"
         CALL abort
      ENDIF
c
c Definir les variables pour enregistrement ulterieur:
c
      ierr = NF_REDEF (mid)
c
      ierr = NF_DEF_VAR (mid,"time", NF_FLOAT,1,idim_t,id_time)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir time"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"long_name",12,"time counter")
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"short_name",4,"time")
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"units",16,"days since 1-1-1")
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"note",27,
     .                       "Il peut etre n importe quoi")
c
      dims3(1) = idim_x
      dims3(2) = idim_y
      dims3(3) = idim_t
c
      ierr = NF_DEF_VAR (mid,"vari",NF_FLOAT,3,dims3,id_vari)
      ierr = NF_PUT_ATT_TEXT(mid,id_vari,"long_name",8,"Variable")
      ierr = NF_PUT_ATT_TEXT(mid,id_vari,"short_name",4,"vari")
      ierr = NF_PUT_ATT_TEXT(mid,id_vari,"units",1,"-")
#ifdef NC_DOUBLE
      ierr = NF_PUT_ATT_DOUBLE(mid,id_vari,"missing_value",
     .                                   NF_FLOAT,1,missing)
#else
      ierr = NF_PUT_ATT_REAL(mid,id_vari,"missing_value",
     .                                   NF_FLOAT,1,missing)
#endif
c
      ierr = NF_ENDDEF(mid)
c
      DO 99999 n = 1, nb
c
#ifdef NC_DOUBLE
        ierr = NF_PUT_VAR1_DOUBLE(mid,id_time,n,FLOAT(n))
#else
        ierr = NF_PUT_VAR1_REAL(mid,id_time,n,FLOAT(n))
#endif
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer time"
           CALL abort
        ENDIF
c
        debu3(1) = 1
        debu3(2) = 1
        debu3(3) = n
        epai3(1) = iim
        epai3(2) = jjm
        epai3(3) = 1
c
#ifdef NC_DOUBLE
        ierr = NF_PUT_VARA_DOUBLE(mid,id_vari,debu3,epai3,vari(1,1,n))
#else
        ierr = NF_PUT_VARA_REAL(mid,id_vari,debu3,epai3,vari(1,1,n))
#endif
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer vari"
           CALL abort
        ENDIF
c
99999 CONTINUE
      ierr = NF_CLOSE(mid)
c
      RETURN 
      END
      SUBROUTINE ecrit_netcdf3d(ficnom,iim,jjm,kkm,x,y,z,
     .                        mask,missing,nb,vari)
      IMPLICIT none
c
      CHARACTER*(*) ficnom
      INTEGER iim, jjm, kkm, nb
      REAL x(iim), y(jjm), z(kkm), mask(iim,jjm)
      REAL vari(iim,jjm,kkm,nb)
      REAL missing
c
#include "netcdf.inc"
c
      INTEGER ierr, mid, varid
      INTEGER idim_x, idim_y, idim_z, idim_t
      INTEGER dims2(2), dims4(4)
c
      INTEGER id_time, id_vari, n
c
      INTEGER debu4(4), epai4(4)
c
c Ouvrir le fichier a ecrire:
c
      ierr = NF_CREATE(ficnom, NF_CLOBBER, mid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme d ouverture du fichier:"//ficnom
         CALL abort
      ENDIF
c
c Preciser quelques attributs globaux:
c
      ierr = NF_PUT_ATT_TEXT (mid, NF_GLOBAL, "title", 29,
     .                       "Ecriture rapide d un champ 3D")
      ierr = NF_PUT_ATT_TEXT (mid, NF_GLOBAL, "model", 33,
     .                       "Resultats issus d un diagnostique")
c
c Definir les dimensions du fichier:
c
      ierr = NF_DEF_DIM(mid,"x",iim,idim_x)
      ierr = NF_DEF_DIM(mid,"y",jjm,idim_y)
      ierr = NF_DEF_DIM(mid,"z",kkm,idim_z)
      ierr = NF_DEF_DIM(mid, "time", NF_UNLIMITED, idim_t)
c
      ierr = NF_ENDDEF(mid) ! sortir du mode de definition
c
c Definir et enregistrer certains champs invariants:
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"x",NF_FLOAT,1,idim_x,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir x"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "long_name", 10,"Longitudes")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "short_name", 1,"x")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 12,"degrees_east")
      ierr = NF_ENDDEF(mid)
#ifdef NC_DOUBLE
      ierr = NF_PUT_VAR_DOUBLE(mid,varid,x)
#else
      ierr = NF_PUT_VAR_REAL(mid,varid,x)
#endif
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer x"
         CALL abort
      ENDIF
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"y",NF_FLOAT,1,idim_y,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir y"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "long_name", 9,"Latitudes")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "short_name", 1,"y")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 13,"degrees_north")
      ierr = NF_ENDDEF(mid)
#ifdef NC_DOUBLE
      ierr = NF_PUT_VAR_DOUBLE(mid,varid,y)
#else
      ierr = NF_PUT_VAR_REAL(mid,varid,y)
#endif
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer y"
         CALL abort
      ENDIF
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"z",NF_FLOAT,1,idim_z,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir z"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "long_name", 9,"Vertical")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "short_name", 1,"z")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 6,"layers")
      ierr = NF_ENDDEF(mid)
#ifdef NC_DOUBLE
      ierr = NF_PUT_VAR_DOUBLE(mid,varid,z)
#else
      ierr = NF_PUT_VAR_REAL(mid,varid,z)
#endif
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer z"
         CALL abort
      ENDIF
c
      dims2(1) = idim_x
      dims2(2) = idim_y
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"mask",NF_FLOAT,2,dims2,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir mask"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid,varid,"long_name",6,"Masque")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "short_name", 4,"mask")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 1,"-")
      ierr = NF_ENDDEF(mid)
#ifdef NC_DOUBLE
      ierr = NF_PUT_VAR_DOUBLE(mid,varid,mask)
#else
      ierr = NF_PUT_VAR_REAL(mid,varid,mask)
#endif
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer mask"
         CALL abort
      ENDIF
c
c Definir les variables pour enregistrement ulterieur:
c
      ierr = NF_REDEF (mid)
c
      ierr = NF_DEF_VAR (mid,"time", NF_FLOAT,1,idim_t,id_time)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir time"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"long_name",12,"time counter")
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"short_name",4,"time")
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"units",16,"days since 1-1-1")
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"note",27,
     .                       "Il peut etre n importe quoi")
c
      dims4(1) = idim_x
      dims4(2) = idim_y
      dims4(3) = idim_z
      dims4(4) = idim_t
c
      ierr = NF_DEF_VAR (mid,"vari",NF_FLOAT,4,dims4,id_vari)
      ierr = NF_PUT_ATT_TEXT(mid,id_vari,"long_name",8,"Variable")
      ierr = NF_PUT_ATT_TEXT(mid,id_vari,"short_name",4,"vari")
      ierr = NF_PUT_ATT_TEXT(mid,id_vari,"units",1,"-")
#ifdef NC_DOUBLE
      ierr = NF_PUT_ATT_DOUBLE(mid,id_vari,"missing_value",
     .                                   NF_FLOAT,1,missing)
#else
      ierr = NF_PUT_ATT_REAL(mid,id_vari,"missing_value",
     .                                   NF_FLOAT,1,missing)
#endif
c
      ierr = NF_ENDDEF(mid)
c
      DO 99999 n = 1, nb
c
#ifdef NC_DOUBLE
        ierr = NF_PUT_VAR1_DOUBLE(mid,id_time,n,FLOAT(n))
#else
        ierr = NF_PUT_VAR1_REAL(mid,id_time,n,FLOAT(n))
#endif
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer time"
           CALL abort
        ENDIF
c
        debu4(1) = 1
        debu4(2) = 1
        debu4(3) = 1
        debu4(4) = n
        epai4(1) = iim
        epai4(2) = jjm
        epai4(3) = kkm
        epai4(4) = 1
c
#ifdef NC_DOUBLE
        ierr = NF_PUT_VARA_DOUBLE(mid,id_vari,debu4,epai4,vari(1,1,1,n))
#else
        ierr = NF_PUT_VARA_REAL(mid,id_vari,debu4,epai4,vari(1,1,1,n))
#endif
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer vari"
           CALL abort
        ENDIF
c
99999 CONTINUE
      ierr = NF_CLOSE(mid)
c
      RETURN
      END
