  PROGRAM orca2lmdz
  USE netcdf
  IMPLICIT none
!
  INTEGER, PARAMETER :: iim=72, jjm=46
  INTEGER :: nb
!
  REAL, DIMENSION(:,:,:), ALLOCATABLE :: slp ! pression au sol
  REAL, DIMENSION(:,:,:), ALLOCATABLE :: t2m ! temperature a 2 m
  REAL, DIMENSION(:,:,:), ALLOCATABLE :: rain ! temperature a 2 m
  REAL, DIMENSION(:,:,:), ALLOCATABLE :: snow ! temperature a 2 m
!
  REAL x(iim), y(jjm)
  REAL, DIMENSION(:), ALLOCATABLE :: time
!
  REAL :: rlon, rlat
  INTEGER :: ipt, jpt
!
! Number of arguments:
  INTEGER :: iargc
!  EXTERNAL :: iargc
  CHARACTER(LEN=40) :: tapename ! file name
!
  INTEGER :: ierr, nid, varid
  INTEGER :: i, j, n
!
!
  i = iargc()
  IF (i.NE.1) THEN
     PRINT*, "Lack of argument (file name), and only one"
     CALL abort
  ENDIF
! Open the data file:
!
  CALL getarg(1,tapename)
  ierr = NF90_OPEN (tapename, NF90_NOWRITE,nid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme d ouverture du fichier:"//tapename
     CALL abort
  ENDIF
!
  ierr = NF90_INQ_DIMID(nid,"x",varid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir DIMidentificateur de x"
     CALL abort
  ENDIF
  ierr = NF90_INQUIRE_DIMENSION(nid,varid,LEN=i)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir la longueur de x"
     CALL abort
  ENDIF
!
  IF (i.NE.iim) THEN
     PRINT*, "Dimension X fausse:", i, iim
     CALL abort
  ENDIF
!
  ierr = NF90_INQ_VARID(nid,"x",varid)
  ierr = NF90_GET_VAR(nid,varid,x,START=(/1/),COUNT=(/iim/))
!
  ierr = NF90_INQ_DIMID(nid,"y",varid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir DIMidentificateur de y"
     CALL abort
  ENDIF
  ierr = NF90_INQUIRE_DIMENSION(nid,varid,LEN=j)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir la longueur de lat"
     CALL abort
  ENDIF
!
  IF (j.NE.jjm) THEN
     PRINT*, "Dimension Y fausse:", j, jjm
     CALL abort
  ENDIF
!
  ierr = NF90_INQ_VARID(nid,"y",varid)
  ierr = NF90_GET_VAR(nid,varid,y,START=(/1/),COUNT=(/jjm/))
!
  ierr = NF90_INQ_DIMID(nid,"time_counter",varid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir identificateur de time_counter"
     CALL abort
  ENDIF
  ierr = NF90_INQUIRE_DIMENSION(nid,varid,LEN=nb)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir la longueur de time_counter"
     CALL abort
  ENDIF
!
  ALLOCATE (time(nb))
!
  ierr = NF90_INQ_VARID(nid,"time_counter",varid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir varID de time_counter"
     CALL abort
  ENDIF
  ierr = NF90_GET_VAR(nid,varid,time,START=(/1/),COUNT=(/nb/))
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour extraire time_counter"
     CALL abort
  ENDIF
!
  PRINT*, "Entrer longitude (-180/+180):"
  READ*, rlon
  PRINT*, "Entrer latitude (-90/+90):"
  READ*, rlat
!
  ipt = 1
  DO i = 2, iim
     IF (x(i-1).LE.rlon .AND. x(i).GT.rlon) THEN
        ipt = i
     ENDIF
  ENDDO
  jpt = 1
  DO j = 2, jjm
     IF (y(j-1).GT.rlat .AND. y(j).LE.rlat) THEN
        jpt = j
     ENDIF
  ENDDO
!
  PRINT*, "Le point choisi est:", rlon,rlat
  PRINT*, "--->", ipt,jpt
!
  ALLOCATE (slp(iim,jjm,nb))
  ierr = NF90_INQ_VARID (nid,"slp",varid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir ID de slp"
     CALL abort
  ENDIF
  ierr = NF90_GET_VAR(nid,varid,slp,START=(/1,1,1/),COUNT=(/iim,jjm,nb/))
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour extraire slp"
     CALL abort
  ENDIF
!
  ALLOCATE (t2m(iim,jjm,nb))
  ierr = NF90_INQ_VARID (nid,"t2m",varid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir ID de t2m"
     CALL abort
  ENDIF
  ierr = NF90_GET_VAR(nid,varid,t2m,START=(/1,1,1/),COUNT=(/iim,jjm,nb/))
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour extraire t2m"
     CALL abort
  ENDIF
!
  ALLOCATE (rain(iim,jjm,nb))
  ierr = NF90_INQ_VARID (nid,"rain",varid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir ID de rain"
     CALL abort
  ENDIF
  ierr = NF90_GET_VAR(nid,varid,rain,START=(/1,1,1/),COUNT=(/iim,jjm,nb/))
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour extraire rain"
     CALL abort
  ENDIF
!
  ALLOCATE (snow(iim,jjm,nb))
  ierr = NF90_INQ_VARID (nid,"snow",varid)
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour avoir ID de snow"
     CALL abort
  ENDIF
  ierr = NF90_GET_VAR(nid,varid,snow,START=(/1,1,1/),COUNT=(/iim,jjm,nb/))
  IF (ierr.NE.NF90_NOERR) THEN
     PRINT*, "Probleme pour extraire snow"
     CALL abort
  ENDIF
!
  DO n = 1, nb
     PRINT*, time(n), slp(ipt,jpt,n), t2m(ipt,jpt,n), &
                      (rain(ipt,jpt,n)+snow(ipt,jpt,n))*86400.0
  ENDDO
!
  ierr = NF90_CLOSE(nid)
!
  STOP 
  END
