      PROGRAM tracer_start
      IMPLICIT NONE
c
c Convert the principal variables of the initial state
c "start.nc" from its staggered grid into a single
c latitude-longitude grid, useful for graphic tool GRADS.
c
c Pour convertir et ranger les variables principales
c de l'etat initial "start.nc" dans un fichier "tmp.nc"
c qui est utilisable par le logiciel graphic "GrADS"
c
c g95 tracer_start.F -fstatic -I$HOME/netcdf/include -L$HOME/netcdf/lib -lnetcdf
c
c Dimensions
c
      INTEGER iim, jjm, llm
      PARAMETER (iim=72,jjm=45,llm=19)
      INTEGER nqmx
      PARAMETER (nqmx=2)
c
c Variables dans "start.nc" 
c (sur la grille Arakawa C et avec le recouvrement periodique):
c
      REAL controle(100)
      REAL rlonu(iim+1)
      REAL rlatu(jjm+1)
      REAL rlonv(iim+1)
      REAL rlatv(jjm)
      REAL ap(llm+1)
      REAL bp(llm+1)
      REAL presnivs(llm+1)
      REAL nivsigs(llm+1)
      REAL nivsig(llm)
      REAL cu(iim+1,jjm+1)
      REAL cv(iim+1,jjm)
      REAL aire(iim+1,jjm+1)
      REAL phisinit(iim+1,jjm+1)
      REAL temps
      REAL vcov(iim+1,jjm,llm),ucov(iim+1,jjm+1,llm)
      REAL teta(iim+1,jjm+1,llm)
      REAL q(iim+1,jjm+1,llm,nqmx)
      REAL ps(iim+1,jjm+1)
      REAL masse(iim+1,jjm+1,llm)
c
c Variables locales:
c
      REAL pres(iim+1,jjm+1,llm)
      REAL pk(iim+1,jjm+1,llm)
      REAL pks
      REAL phi(iim+1,jjm+1,llm)
c
c Variables physiques obtenues:
c (sur une grille unique: points scalaires, et sans recouvrement)
c
      REAL zufi(iim,jjm+1,llm), zvfi(iim,jjm+1,llm)
      REAL zt(iim,jjm+1,llm), zphi(iim,jjm+1,llm)
      REAL zaire(iim,jjm+1)
      REAL zphis(iim,jjm+1)
      REAL zpres(iim,jjm+1,llm)
c
c Interpoler les variables physiques aux niveaux pression standard:
c
      INTEGER std_llm ! nombre de niveaux  de pression  en sortie
      PARAMETER (std_llm = 15)
c
      REAL std_hpa(std_llm), zmb
      REAL std_u(iim,jjm+1,std_llm), std_v(iim,jjm+1,std_llm)
      REAL std_t(iim,jjm+1,std_llm), std_g(iim,jjm+1,std_llm)
      INTEGER iwork1(iim,jjm+1), iwork2(iim,jjm+1)
c
c Constantes:
c
      REAL cpp, kappa, preff, pi
      PARAMETER (cpp=1004.70885)
      PARAMETER (kappa=0.2857143)
      PARAMETER (preff= 101325.)
c
c Variables locales:
c
      INTEGER i, j, k
      REAL x(iim), y(jjm+1)
c
c Preciser ici les niveaux standard:
c
      DATA (std_hpa(k),k=1,std_llm)
     .  /1000., 925., 850.,  700., 600., 500. ,
     .   400., 300., 250., 200., 150.,100.,70., 50.,  10. /
c-----------------------------------------------------------------------
c
      pi = 4.0 * ATAN(1.0)
c
c Lecture du fichier "start.nc":
c
      CALL dynetat0(iim,jjm,llm,nqmx,"start.nc",
     .              controle,rlonu,rlatu,rlonv,rlatv,
     .              nivsigs,nivsig,ap,bp,presnivs,
     .              cu,cv,aire,phisinit,temps,vcov,ucov,
     .              teta,q,masse,ps)
c
c Calculer la grille unique et finale (points scalaires):
c
      DO i = 1, iim
         x(i) = rlonv(i)/pi*180.0
      ENDDO
      DO j = 1, jjm+1
         y(j) = rlatu(j)/pi*180.0
      ENDDO
c
c Aire de chaque maille (m2) et geopotentiel du sol (m m/s2):
c
      DO j = 1, jjm+1
      DO i = 1, iim
         zaire(i,j) = aire(i,j)
         zphis(i,j) = phisinit(i,j)
      ENDDO
      ENDDO
c
c A partir de la pression au sol, on calcule la pression "pres"
c (pk = Cp * (pres/preff)**kappa):
c
      CALL pression((iim+1)*(jjm+1), llm, ap, bp, ps, pk, pres)
c
c Calculer le geopotentiel:
c
      DO j = 1, jjm+1
      DO i = 1, iim+1
      pks = (ps(i,j)/preff)**kappa * cpp
      phi(i,j,1) = phisinit(i,j) + teta(i,j,1)*(pks-pk(i,j,1))
      ENDDO
      ENDDO
      DO k = 2, llm
      DO j = 1, jjm+1
      DO i = 1, iim+1
        phi(i,j,k) = phi(i,j,k-1) + 0.5 * (teta(i,j,k)+teta(i,j,k-1))
     *                                  * (pk(i,j,k-1)-pk(i,j,k))
      ENDDO
      ENDDO
      ENDDO
c
c Rassembler les variables sur la grille unique:
c
      CALL dyn2phy(iim,jjm,llm,
     .             pk,pres,ucov,cu,vcov,cv,teta,phi,
     .             zt,zphi,zufi,zvfi,zpres)
c
c Interpoler les variables sur les niveaux standard:
c
      DO k = 1, std_llm
         zmb = std_hpa(k)*100.0
         CALL plevel(iim*(jjm+1),llm,zpres, zufi,zvfi,zt,zphi,zmb,
     .               std_u(1,1,k),std_v(1,1,k),
     .               std_t(1,1,k),std_g(1,1,k), iwork1,iwork2)
      ENDDO
c
c Ecrire les variables dans le fichier "tmp.nc":
c
      CALL ecrire("tmp.nc",iim,jjm+1,std_llm,x,y,std_hpa,zphis,zaire,
     .            std_u,std_v,std_g,std_t)
c-----------------------------------------------------------------------
      STOP
      END
      SUBROUTINE dynetat0(iim,jjm,llm,nqmx,fichnom,
     .                    controle,rlonu,rlatu,rlonv,rlatv,
     .                    nivsigs,nivsig,ap,bp,presnivs,
     .                    cu,cv,aire,phisinit,temps,vcov,ucov,
     .                    teta,q,masse,ps)
      IMPLICIT NONE
#include "netcdf.inc"
c
ccc dimensions
      INTEGER iim, jjm, llm
      INTEGER nqmx
ccc dimensions
c
      CHARACTER*(*) fichnom
      REAL controle(100)
      REAL rlonu(iim+1)
      REAL rlatu(jjm+1)
      REAL rlonv(iim+1)
      REAL rlatv(jjm)
      REAL ap(llm+1)
      REAL bp(llm+1)
      REAL presnivs(llm+1)
      REAL nivsigs(llm+1)
      REAL nivsig(llm)
      REAL cu(iim+1,jjm+1)
      REAL cv(iim+1,jjm)
      REAL aire(iim+1,jjm+1)
      REAL phisinit(iim+1,jjm+1)
      REAL temps
      REAL vcov(iim+1,jjm,llm),ucov(iim+1,jjm+1,llm) 
      REAL teta(iim+1,jjm+1,llm)
      REAL q(iim+1,jjm+1,llm,nqmx)
      REAL ps(iim+1,jjm+1)
      REAL masse(iim+1,jjm+1,llm)

c   Variables 
c
      INTEGER iq
      INTEGER ierr, nid, nvarid
      CHARACTER  str3*3

c-----------------------------------------------------------------------

c  Ouverture NetCDF du fichier etat initial

      ierr = NF_OPEN (fichnom, NF_NOWRITE,nid)
      IF (ierr.NE.NF_NOERR) THEN
        write(6,*)' Pb d''ouverture du fichier start.nc'
        write(6,*)' ierr = ', ierr
        CALL ABORT
      ENDIF

c
      ierr = NF_INQ_VARID (nid, "controle", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <controle> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, controle)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, controle)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echoue pour <controle>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "rlonu", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <rlonu> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, rlonu)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, rlonu)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <rlonu>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "rlatu", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <rlatu> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, rlatu)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, rlatu)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <rlatu>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "rlonv", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <rlonv> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, rlonv)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, rlonv)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <rlonv>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "rlatv", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <rlatv> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, rlatv)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, rlatv)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour rlatv"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "nivsigs", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <nivsigs> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, nivsigs)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, nivsigs)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour nivsigs"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "nivsig", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <nivsig> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, nivsig)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, nivsig)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour nivsig"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "ap", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <ap> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, ap)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, ap)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour ap"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "bp", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <bp> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, bp)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, bp)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour bp"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "presnivs", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <presnivs> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, presnivs)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, presnivs)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour presnivs"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "cu", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <cu> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, cu)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, cu)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <cu>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "cv", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <cv> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, cv)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, cv)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <cv>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "aire", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <aire> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, aire)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, aire)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <aire>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "phisinit", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <phisinit> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, phisinit)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, phisinit)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <phisinit>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "temps", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <temps> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, temps)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, temps)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee <temps>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "ucov", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <ucov> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, ucov)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, ucov)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <ucov>"
         CALL abort
      ENDIF
 
      ierr = NF_INQ_VARID (nid, "vcov", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <vcov> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, vcov)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, vcov)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <vcov>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "teta", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <teta> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, teta)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, teta)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <teta>"
         CALL abort
      ENDIF


      IF(nqmx.GE.1) THEN
      DO iq=1,nqmx
        str3(1:1)='q'
        IF(iq.GT.99) THEN
           PRINT*, "Trop de traceurs"
           CALL abort
        ENDIF
        WRITE(str3(2:3),'(i2.2)') iq
        ierr =  NF_INQ_VARID (nid, str3, nvarid)
        IF (ierr .NE. NF_NOERR) THEN
           PRINT*, "dynetat0: Le champ <"//str3//"> est absent"
           PRINT*, "          Il est donc initialise a zero"
           CALL initial0((iim+1)*(jjm+1)*llm,q(1,1,1,iq))
        ELSE
#ifdef NC_DOUBLE
          ierr = NF_GET_VAR_DOUBLE(nid, nvarid, q(1,1,1,iq))
#else
          ierr = NF_GET_VAR_REAL(nid, nvarid, q(1,1,1,iq))
#endif
          IF (ierr .NE. NF_NOERR) THEN
             PRINT*, "dynetat0: Lecture echouee pour "//str3
             CALL abort
          ENDIF
        ENDIF
      ENDDO
      ENDIF

      ierr = NF_INQ_VARID (nid, "masse", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <masse> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, masse)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, masse)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <masse>"
         CALL abort
      ENDIF

      ierr = NF_INQ_VARID (nid, "ps", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Le champ <ps> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VAR_DOUBLE(nid, nvarid, ps)
#else
      ierr = NF_GET_VAR_REAL(nid, nvarid, ps)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "dynetat0: Lecture echouee pour <ps>"
         CALL abort
      ENDIF

      ierr = NF_CLOSE(nid)

      RETURN
      END

      SUBROUTINE pression(ngrid, llm, ap, bp, ps, pk, pres)
      IMPLICIT NONE
c
      INTEGER ngrid, llm
c
      INTEGER l,ij

      REAL ap(llm+1), bp(llm+1), ps(ngrid)
      REAL pres(ngrid,llm)
c
      REAL pk(ngrid,llm)
      REAL p(ngrid,llm+1), pks(ngrid)
      REAL alpha(ngrid,llm),beta(ngrid,llm)
c
      REAL dellta
      REAL cpp, kappa, unpl2k, preff
      PARAMETER (cpp=1004.70885)
      PARAMETER (kappa=0.2857143)
      PARAMETER (unpl2k= 1.+ 2.*kappa)
      PARAMETER (preff= 101325.)

      DO  l    = 1, llm+1
      DO  ij   = 1, ngrid
         p(ij,l) = ap(l) + bp(l) * ps(ij)
      ENDDO
      ENDDO
c
      DO   ij  = 1, ngrid
       pks(ij) = cpp * ( ps(ij)/preff ) ** kappa
      ENDDO
c
      DO     ij      = 1, ngrid
       alpha(ij,llm) = 0.
       beta (ij,llm) = 1./ unpl2k
      ENDDO
c
      DO l = llm -1 , 2 , -1
      DO ij = 1, ngrid
        dellta = p(ij,l)* unpl2k + p(ij,l+1)* ( beta(ij,l+1)-unpl2k )
        alpha(ij,l)  = - p(ij,l+1) / dellta * alpha(ij,l+1)
        beta (ij,l)  =   p(ij,l  ) / dellta
      ENDDO
      ENDDO
c
      DO   ij   = 1, ngrid
       pk(ij,1) = ( p(ij,1)*pks(ij) - 0.5*alpha(ij,2)*p(ij,2) )  /
     *    (  p(ij,1)* (1.+kappa) + 0.5*( beta(ij,2)-unpl2k )* p(ij,2) )
      ENDDO
      DO l = 2, llm
      DO   ij   = 1, ngrid
         pk(ij,l) = alpha(ij,l) + beta(ij,l) * pk(ij,l-1)
      ENDDO
      ENDDO
c
      DO l = 1, llm
      DO ij = 1, ngrid
         pres(ij,l) = preff * (pk(ij,l)/cpp)**(1.0/kappa)
      ENDDO
      ENDDO
c
      RETURN
      END

      SUBROUTINE dyn2phy(iim,jjm,llm,
     .                   pk,pres,ucov,cu,vcov,cv,teta,phi,
     .                   zt,zphi,zufi,zvfi,zpres)
      IMPLICIT none
c
      INTEGER iim, jjm, llm
c
      REAL pk(iim+1,jjm+1,llm)
      REAL vcov(iim+1,jjm,llm)
      REAL ucov(iim+1,jjm+1,llm)
      REAL teta(iim+1,jjm+1,llm)
      REAL phi(iim+1,jjm+1,llm)
      REAL pres(iim+1,jjm+1,llm)
      REAL cu(iim+1,jjm+1)
      REAL cv(iim+1,jjm)
      REAL rlonu(iim+1)
      REAL rlonv(iim+1)
c    
      REAL zufi(iim,jjm+1,llm), zvfi(iim,jjm+1,llm)
      REAL zt(iim,jjm+1,llm), zphi(iim,jjm+1,llm)
      REAL zpres(iim,jjm+1,llm)
c
      REAL cpp, pi
      PARAMETER (cpp=1004.70885)
c
      INTEGER i, j, l
c
      pi = 4.0*ATAN(1.0)
c
c Champs T, Z:
c
      DO l = 1, llm
      DO j = 1, jjm+1
      DO i = 1, iim
         zt(i,j,l)   =  teta(i,j,l) * pk(i,j,l) / cpp
         zphi(i,j,l)   =  phi(i,j,l)
         zpres(i,j,l)   =  pres(i,j,l)
      ENDDO
      ENDDO
      ENDDO
c
c Champ u:
c
      DO l=1,llm
      DO j=2,jjm
         i = 1
         zufi(i,j,l)=0.5*(ucov(iim,j,l)/cu(iim,j)+ucov(1,j,l)/cu(1,j))
         DO i=2,iim
           zufi(i,j,l)=0.5*(ucov(i-1,j,l)/cu(i-1,j)+ucov(i,j,l)/cu(i,j))
         ENDDO
      ENDDO
      ENDDO
c
c Champ v:
c
      DO l=1,llm
      DO j=2,jjm
      DO i=1,iim
         zvfi(i,j,l)=0.5*(vcov(i,j-1,l)/cv(i,j-1)+vcov(i,j,l)/cv(i,j))
      ENDDO
      ENDDO
      ENDDO
c
c Champs de vents aux pole nord
c        U = 1 / pi  *  integrale [ v * cos(long) * d long ]
c        V = 1 / pi  *  integrale [ v * sin(long) * d long ]
c
      j = 1
      DO l = 1, llm
         zufi(1,j,l)  = COS(rlonv(1))*(rlonu(1)-rlonu(iim)+2.*pi)
     .                             *vcov(1,1,l)/cv(1,1)
         zvfi(1,j,l)  = SIN(rlonv(1))*(rlonu(1)-rlonu(iim)+2.*pi)
     .                             *vcov(1,1,l)/cv(1,1)
         DO i = 2, iim
            zufi(1,j,l)  = zufi(1,j,l) + COS(rlonv(i)) 
     .                             * (rlonu(i)-rlonu(i-1))
     .                             * vcov(i,1,l)/cv(i,1)
            zvfi(1,j,l)  = zvfi(1,j,l) + SIN(rlonv(i)) 
     .                             * (rlonu(i)-rlonu(i-1))
     .                             * vcov(i,1,l)/cv(i,1)
         ENDDO
         zufi(1,j,l)  = zufi(1,j,l) / pi
         zvfi(1,j,l)  = zvfi(1,j,l) / pi
         DO i = 2, iim
            zufi(i,j,l) = zufi(1,j,l)
            zvfi(i,j,l) = zvfi(1,j,l)
         ENDDO
      ENDDO
c
c Camps de vents aux pole sud:
c
c        U = 1 / pi  *  integrale [ v * cos(long) * d long ]
c        V = 1 / pi  *  integrale [ v * sin(long) * d long ]
c
      j = jjm+1
      DO l = 1, llm
         zufi(1,j,l)  = COS(rlonv(1))*(rlonu(1)-rlonu(iim)+2.*pi)
     .                             *vcov(1,jjm,l)/cv(1,jjm)
         zvfi(1,j,l)  = SIN(rlonv(1))*(rlonu(1)-rlonu(iim)+2.*pi)
     .                             *vcov(1,jjm,l)/cv(1,jjm)
         DO i = 2, iim
            zufi(1,j,l)  = zufi(1,j,l) + COS(rlonv(i))
     .                             * (rlonu(i)-rlonu(i-1))
     .                             * vcov(i,jjm,l)/cv(i,jjm)
            zvfi(1,j,l)  = zvfi(1,j,l) + SIN(rlonv(i))
     .                             * (rlonu(i)-rlonu(i-1))
     .                             * vcov(i,jjm,l)/cv(i,jjm)
         ENDDO
         zufi(1,j,l)  = zufi(1,j,l) / pi
         zvfi(1,j,l)  = zvfi(1,j,l) / pi
         DO i = 2, iim
            zufi(i,j,l) = zufi(1,j,l)
            zvfi(i,j,l) = zvfi(1,j,l)
         ENDDO
      ENDDO 
c
      RETURN
      END
      SUBROUTINE initial0(n,x)
      IMPLICIT NONE
      INTEGER n,i
      REAL x(n)
      DO 10 i=1,n
         x(i)=0.
10    CONTINUE
      RETURN
      END
      SUBROUTINE plevel(klon, klev, pls,
     .       u,v,t,g, plvl,
     .    ulvl,vlvl,tlvl,glvl, lt,lb)
      IMPLICIT none
c
c
c
c Interpoler des champs 3-D u, v et g du modele a un niveau de
c pression donnee (plvl)
c INPUT:  klon ----- nombre de points
c         klev ----- nombre de couches
c         u -------- vitesse u
c         v -------- vitesse v
c         t -------- temperature
c         g -------- geopotentiel
c         plvl ----- pression du niveau a obtenir
c 
c OUTPUT: ulvl, vlvl, tlvl, glvl
c 
c Tableaux de travail: lt, lb
c
      INTEGER klon, klev 
      REAL u(klon,klev), v(klon,klev), t(klon,klev)
      REAL pls(klon,klev)
      REAL g(klon,klev)

      REAL plvl
      REAL ulvl(klon), vlvl(klon), tlvl(klon)
      REAL glvl(klon)
      INTEGER lt(klon), lb(klon)
c
      REAL ptop, pbot, aist, aisb
      INTEGER i, k
c 
c Chercher les 2 couches les plus proches du niveau a obtenir
c 
c Eventuellement, faire l'extrapolation a partir des deux couches
c les plus basses ou les deux couches les plus hautes:
      DO 130 i = 1, klon
         IF ( ABS(plvl-pls(i,klev) ) .LT.
     .        ABS(plvl-pls(i,1)) ) THEN
            lt(i) = klev     ! 2
            lb(i) = klev-1   ! 1
         ELSE
            lt(i) = 2
            lb(i) = 1
         ENDIF
  130 CONTINUE 
      DO 150 k = 1, klev-1
         DO 140 i = 1, klon
            pbot = pls(i,k)
            ptop = pls(i,k+1)
            IF (ptop.LE.plvl .AND. pbot.GE.plvl) THEN
               lt(i) = k+1
               lb(i) = k
            ENDIF
  140    CONTINUE
  150 CONTINUE
c 
c Interpolation lineaire:
c
      DO 160 i = 1, klon
c interpolation en logarithme de pression:
c
c 
c ...   Modif . P. Le Van    ( 20/01/98) ....


        aist = LOG( pls(i,lb(i))/ plvl )
     .       / LOG( pls(i,lb(i))/ pls(i,lt(i)) )
        aisb = LOG( plvl / pls(i,lt(i)) )
     .       / LOG( pls(i,lb(i))/ pls(i,lt(i)))
        ulvl(i) = u(i,lb(i)) * aisb + u(i,lt(i)) * aist
        vlvl(i) = v(i,lb(i)) * aisb + v(i,lt(i)) * aist
        tlvl(i) = t(i,lb(i)) * aisb + t(i,lt(i)) * aist
        glvl(i) = g(i,lb(i)) * aisb + g(i,lt(i)) * aist
  160 CONTINUE
c 
c Je mets les vents a zero quand je rencontre une montagne
      DO i = 1, klon
      IF (pls(i,1).LT.plvl) THEN
         ulvl(i) = 0.0
         vlvl(i) = 0.0
      ENDIF
      ENDDO
c
      RETURN
      END

      SUBROUTINE ecrire(fich,iim,jjm,std_llm,x,y,std_hpa,phis,aire,
     .                  std_u,std_v,std_g,std_t)
      IMPLICIT none
c
#include "netcdf.inc"
c
      CHARACTER*(*) fich
      INTEGER iim, jjm, std_llm
      REAL x(iim), y(jjm), std_hpa(std_llm)
      REAL phis(iim,jjm), aire(iim,jjm)
c
      REAL std_u(iim,jjm,std_llm), std_v(iim,jjm,std_llm)
      REAL std_t(iim,jjm,std_llm), std_g(iim,jjm,std_llm)
      INTEGER id_vitu, id_vitv
      INTEGER id_geop, id_temp
      INTEGER debu4(4), epai4(4)
c
      INTEGER ierr, nid, mid, varid
      INTEGER idim_x, idim_y, idim_z, idim_t
      INTEGER dims2(2), dims4(4)
c
      INTEGER id_time
c
c Ouvrir le fichier a ecrire:
c
      ierr = NF_CREATE(fich, NF_CLOBBER, mid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Dans ecrire: Probleme d ouverture du fichier"
         CALL abort
      ENDIF
c
c Preciser quelques attributs globaux:
c
      ierr = NF_PUT_ATT_TEXT (mid, NF_GLOBAL, "title", 31,
     .                       "Fichier en coordonnees pression")
      ierr = NF_PUT_ATT_TEXT (mid, NF_GLOBAL, "model", 30,
     .                       "Modele de circulation generale")
c
c Definir les dimensions du fichier:
c
      ierr = NF_DEF_DIM(mid,"x",iim,idim_x)
      ierr = NF_DEF_DIM(mid,"y",jjm,idim_y)
      ierr = NF_DEF_DIM(mid,"z",std_llm,idim_z)
      ierr = NF_DEF_DIM(mid, "time", NF_UNLIMITED, idim_t)
c
      ierr = NF_ENDDEF(mid) ! sortir du mode de definition
c
c Definir et enregistrer certains champs invariants:
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"x",NF_FLOAT,1,idim_x,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir x"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "title", 10,"Longitudes")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 12,"degrees_east")
      ierr = NF_ENDDEF(mid)
      ierr = NF_PUT_VAR_REAL(mid,varid,x)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer x"
         CALL abort
      ENDIF
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"y",NF_FLOAT,1,idim_y,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir y"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "title", 9,"Latitudes")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 13,"degrees_north")
      ierr = NF_ENDDEF(mid)
      ierr = NF_PUT_VAR_REAL(mid,varid,y)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer y"
         CALL abort
      ENDIF
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"z",NF_FLOAT,1,idim_z,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir z"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "title", 7,"Presure")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 9,"millibars")
      ierr = NF_ENDDEF(mid)
      ierr = NF_PUT_VAR_REAL(mid,varid,std_hpa)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer z"
         CALL abort
      ENDIF
c
      dims2(1) = idim_x
      dims2(2) = idim_y
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"phis",NF_FLOAT,2,dims2,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir phis"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "title", 14,"Surface height")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 1,"-")
      ierr = NF_ENDDEF(mid)
      ierr = NF_PUT_VAR_REAL(mid,varid,phis)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer phis"
         CALL abort
      ENDIF
c
      ierr = NF_REDEF (mid)
      ierr = NF_DEF_VAR (mid,"aire",NF_FLOAT,2,dims2,varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir aire"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT (mid, varid, "title", 9,"Grid aire")
      ierr = NF_PUT_ATT_TEXT (mid, varid, "units", 1,"-")
      ierr = NF_ENDDEF(mid)
      ierr = NF_PUT_VAR_REAL(mid,varid,aire)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour enregistrer aire"
         CALL abort
      ENDIF
c
c Definir les variables pour enregistrement ulterieur:
c
      ierr = NF_REDEF (mid)
c
      ierr = NF_DEF_VAR (mid,"time", NF_FLOAT,1,idim_t,id_time)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour definir time"
         CALL abort
      ENDIF
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"title",12,"time counter")
      ierr = NF_PUT_ATT_TEXT(mid,id_time,"units",16,"days since 1-1-1")
c
      dims4(1) = idim_x
      dims4(2) = idim_y
      dims4(3) = idim_z
      dims4(4) = idim_t
c
      ierr = NF_DEF_VAR (mid,"temp",NF_FLOAT,4,dims4,id_temp)
      ierr = NF_PUT_ATT_TEXT(mid,id_temp,"title",15,"Air temperature")
      ierr = NF_PUT_ATT_TEXT(mid,id_temp,"units",1,"K")
c
      ierr = NF_DEF_VAR (mid,"geop",NF_FLOAT,4,dims4,id_geop)
      ierr = NF_PUT_ATT_TEXT(mid,id_geop,"title",13,"Geopo. height")
      ierr = NF_PUT_ATT_TEXT(mid,id_geop,"units",5,"m2/s2")
c
      ierr = NF_DEF_VAR (mid,"vitu",NF_FLOAT,4,dims4,id_vitu)
      ierr = NF_PUT_ATT_TEXT(mid,id_vitu,"title",10,"Zonal wind")
      ierr = NF_PUT_ATT_TEXT(mid,id_vitu,"units",3,"m/s")
c
      ierr = NF_DEF_VAR (mid,"vitv",NF_FLOAT,4,dims4,id_vitv)
      ierr = NF_PUT_ATT_TEXT(mid,id_vitv,"title",15,"Meridional wind")
      ierr = NF_PUT_ATT_TEXT(mid,id_vitv,"units",3,"m/s")
c
      ierr = NF_ENDDEF(mid)
c
        ierr = NF_PUT_VAR1_REAL(mid,id_time,1,1.0)
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer time"
           CALL abort
        ENDIF
c
        debu4(1) = 1
        debu4(2) = 1
        debu4(3) = 1
        debu4(4) = 1
        epai4(1) = iim
        epai4(2) = jjm
        epai4(3) = std_llm
        epai4(4) = 1
c
        ierr = NF_PUT_VARA_REAL(mid,id_temp,debu4,epai4,std_t)
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer temp"
           CALL abort
        ENDIF
c
        ierr = NF_PUT_VARA_REAL(mid,id_geop,debu4,epai4,std_g)
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer geop"
           CALL abort
        ENDIF
c
        ierr = NF_PUT_VARA_REAL(mid,id_vitu,debu4,epai4,std_u)
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer vitu"
           CALL abort
        ENDIF
c
        ierr = NF_PUT_VARA_REAL(mid,id_vitv,debu4,epai4,std_v)
        IF (ierr.NE.NF_NOERR) THEN
           PRINT*, "Probleme pour enregistrer vitv"
           CALL abort
        ENDIF
c
      ierr = NF_CLOSE(mid)

      RETURN
      END
