      SUBROUTINE condsurf( jour, jourvrai, pctsrf,
     s                    lmt_sst,lmt_alb,lmt_rug,lmt_bils )
      IMPLICIT none
c
c Lire les conditions aux limites du modele.
c -----------------------------------------
c jour     : input  , numero du jour a lire
c jourvrai : input  , vrai jour de la simulation  
c
c pctsrf:  sous-maille fractionnelle, la somme doit = 1
c lmt_sst: temperature de la surface oceanique
c lmt_alb: albedo du sol
c lmt_rug: longeur de rugosite du sol
c lmt_bils: bilan chaleur au sol (a utiliser pour "slab-ocean")
c
#include "netcdf.inc"
      INTEGER nid, nvarid
      INTEGER debut(2)
      INTEGER epais(2)
       real chmin,chmax
      INTEGER lnblnk
      EXTERNAL lnblnk
c
#include "dimensions.h"
#include "dimphy.h"
#include "indicesol.h"
#include "temps.h"
#include "clesphys.h"
c
c newlmt indique l'utilisation de la sous-maille fractionnelle,
c tandis que l'ancien regime utilisait l'indicateur du sol (0,1,2,3).

      LOGICAL newlmt
      PARAMETER (newlmt=.FALSE.)

      INTEGER     nannemax
      PARAMETER ( nannemax = 60 )
c
      INTEGER jour,jourvrai
      REAL lmt_nat(klon) ! indicateur de la nature du sol
      REAL pctsrf(klon,nbsrf) ! sous-maille fractionnelle
      REAL lmt_sst(klon) ! temperature de la surface oceanique
      REAL lmt_alb(klon) ! albedo du sol
      REAL lmt_rug(klon) ! longeur de rugosite du sol
      REAL lmt_bils(klon)
c
c Variables locales:
      REAL shijian(360)
      INTEGER ig, i, j, kt, ierr, n, nb, n_ok
      LOGICAL ok
      INTEGER anneelim,anneemax
      CHARACTER*20 fich
c special f_modele_c
ccc      REAL cpl_sst(iim,jjm+1), cpl_sic(iim,jjm+1)
ccc      INTEGER deb(3), epa(3)
c special f_modele_c
cc
cc   .....................................................................
cc
cc    Pour lire le fichier limit correspondant vraiment  a l'annee de la
cc     simulation en cours , il suffit de mettre  ok_limitvrai = .TRUE.
cc
cc   ......................................................................
c
c
      IF (jour.LT.0 .OR. jour.GT.(360-1)) THEN
         PRINT*,'Le jour demande n est pas correct: ', jour
         CALL ABORT
      ENDIF
c
c  .............   modif  (  P. Le Van )  ...........

       anneelim  = anne_ini
       anneemax  = anne_ini + nannemax
c
c
       IF( ok_limitvrai )       THEN
          DO  kt = 1, nannemax
            IF(jourvrai.LE. (kt-1)*360 + 359  )  THEN
              WRITE(fich,'("limit",i4,".nc")') anneelim
              PRINT *,' Fichier  Limite ',fich
              GO TO 100
             ENDIF
           anneelim = anneelim + 1
          ENDDO

         PRINT *,' PBS ! Le jour a lire sur le fichier limit ne se '
         PRINT *,' trouve pas sur les ',nannemax,' annees a partir de '
         PRINT *,' l annee de debut', anne_ini
           CALL EXIT(1)
c
100     CONTINUE
c
       ELSE
     
ccc            WRITE(fich,'("limit",i4,".nc")')  anne_ini
            WRITE(fich,'("limit.nc")')
            PRINT *,' Fichier  Limite ',fich
       ENDIF
c
c  ........... ( fin   modif   P. Le Van  ) ............
c
c Ouvrir le fichier en format NetCDF:
c
      ierr = NF_OPEN (fich, NF_NOWRITE,nid)
      IF (ierr.NE.NF_NOERR) THEN
        WRITE(6,*)' Pb d''ouverture du fichier ', fich
        WRITE(6,*)' Le fichier limit ',fich,' (avec 4 chiffres , pour' 
        WRITE(6,*)'       l an 2000 )  ,  n existe  pas !  ' 
        WRITE(6,*)' ierr = ', ierr
        CALL EXIT(1)
      ENDIF
c
      ierr = NF_INQ_DIMID(nid,"time",nvarid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "condsurf: Probleme pour avoir DIMID de time"
         CALL abort
      ENDIF
      ierr = NF_INQ_DIMLEN(nid,nvarid,nb)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "condsurf: Probleme pour avoir DIMLEN de time"
         CALL abort
      ENDIF
c
      ierr = NF_INQ_VARID(nid,"TEMPS", nvarid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour avoir VARID de TEMPS"
         CALL abort
      ENDIF
      ierr = NF_GET_VARA_REAL(nid,nvarid,1,nb,shijian)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour extraire variable TEMPS"
         CALL abort
      ENDIF
c
      n_ok = 0
      DO n = 1, nb
         IF (NINT(shijian(n)).EQ.(jour+1)) n_ok = n
      ENDDO
      IF (n_ok.EQ.0) THEN
         PRINT*, 'condsurf: Le jour demande est absent du fichier'
         CALL abort
      ENDIF
c
c La tranche de donnees a lire:
c
      debut(1) = 1
      debut(2) = n_ok
      epais(1) = klon
      epais(2) = 1
c
      IF (newlmt) THEN
c
c Fraction "ocean":
      ierr = NF_INQ_VARID (nid, "FOCE", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <FOCE> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid,nvarid,debut,epais,pctsrf(1,is_oce))
#else
      ierr = NF_GET_VARA_REAL(nid,nvarid,debut,epais,pctsrf(1,is_oce))
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Lecture echouee pour <FOCE>"
         CALL abort
      ENDIF
c
c Fraction "glace de mer":
      ierr = NF_INQ_VARID (nid, "FSIC", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <FSIC> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid,nvarid,debut,epais,pctsrf(1,is_sic))
#else
      ierr = NF_GET_VARA_REAL(nid,nvarid,debut,epais,pctsrf(1,is_sic))
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Lecture echouee pour <FSIC>"
         CALL abort
      ENDIF
c
c Fraction "terre":
      ierr = NF_INQ_VARID (nid, "FTER", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <FTER> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid,nvarid,debut,epais,pctsrf(1,is_ter))
#else
      ierr = NF_GET_VARA_REAL(nid,nvarid,debut,epais,pctsrf(1,is_ter))
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Lecture echouee pour <FTER>"
         CALL abort
      ENDIF
c
c Fraction "glacier terre":
      ierr = NF_INQ_VARID (nid, "FLIC", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <FLIC> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid,nvarid,debut,epais,pctsrf(1,is_lic))
#else
      ierr = NF_GET_VARA_REAL(nid,nvarid,debut,epais,pctsrf(1,is_lic))
#endif
      IF (ierr .NE. 0) THEN
         PRINT*, "condsurf: Lecture echouee pour <FLIC>"
         CALL abort
      ENDIF
c
      ELSE ! test sur newlmt
c
c Indicateur de la nature du sol (0,1,2,3):
      ierr = NF_INQ_VARID (nid, "NAT", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <NAT> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid, nvarid,debut,epais,lmt_nat)
#else
      ierr = NF_GET_VARA_REAL(nid, nvarid,debut,epais,lmt_nat)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Lecture echouee pour <NAT>"
         CALL abort
      ENDIF
c
      DO ig = 1, klon
         pctsrf(ig,is_oce) = 0.0
         pctsrf(ig,is_ter) = 0.0
         pctsrf(ig,is_lic) = 0.0
         pctsrf(ig,is_sic) = 0.0
      ENDDO
      ok = .TRUE.
      DO ig = 1, klon
      IF (NINT(lmt_nat(ig)).EQ.0) THEN
         pctsrf(ig,is_oce) = 1.0
      ELSE IF (NINT(lmt_nat(ig)).EQ.1) THEN
         pctsrf(ig,is_ter) = 1.0
      ELSE IF (NINT(lmt_nat(ig)).EQ.2) THEN
         pctsrf(ig,is_lic) = 1.0
      ELSE IF (NINT(lmt_nat(ig)).EQ.3) THEN
         pctsrf(ig,is_sic) = 1.0
      ELSE
         ok = .FALSE.
      ENDIF
      ENDDO
      IF (.NOT.ok) THEN
         PRINT*, "valeur fausse pour lmt_nat:", lmt_nat
         CALL abort
      ENDIF
c
      ENDIF ! fin de test sur newlmt
c
c Sea surface temperature:
      ierr = NF_INQ_VARID (nid, "SST", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <SST> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid, nvarid,debut,epais,lmt_sst)
#else
      ierr = NF_GET_VARA_REAL(nid, nvarid,debut,epais,lmt_sst)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Lecture echouee pour <SST>"
         CALL abort
      ENDIF
c
c Albedo de surface:
      ierr = NF_INQ_VARID (nid, "ALB", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <ALB> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid, nvarid,debut,epais,lmt_alb)
#else
      ierr = NF_GET_VARA_REAL(nid, nvarid,debut,epais,lmt_alb)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Lecture echouee pour <ALB>"
         CALL abort
      ENDIF
c
c Longueur de rugosite au sol:
      ierr = NF_INQ_VARID (nid, "RUG", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <RUG> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid, nvarid,debut,epais,lmt_rug)
#else
      ierr = NF_GET_VARA_REAL(nid, nvarid,debut,epais,lmt_rug)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Lecture echouee pour <RUG>"
         CALL abort
      ENDIF
c
c Bilan flux de chaleur au sol:
      ierr = NF_INQ_VARID (nid, "BILS", nvarid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Le champ <BILS> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid, nvarid,debut,epais,lmt_bils)
#else
      ierr = NF_GET_VARA_REAL(nid, nvarid,debut,epais,lmt_bils)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "condsurf: Lecture echouee pour <BILS>"
         CALL abort
      ENDIF
c
c Fermer le fichier:
c
      ierr = NF_CLOSE(nid)
c
c special f_modele_c
ccc      ierr = NF_OPEN ("tsol_sicf.nc", NF_NOWRITE,nid)
ccc      IF (ierr.NE.NF_NOERR) THEN
ccc        WRITE(6,*)' Pb d''ouverture du fichier tsol_sicf.nc'
ccc        CALL abort
ccc      ENDIF
ccc      deb(1) = 1
ccc      deb(2) = 1
ccc      deb(3) = jour + 1
ccc      epa(1) = iim
ccc      epa(2) = jjm + 1
ccc      epa(3) = 1
ccc      ierr = NF_INQ_VARID (nid, "tsol", nvarid)
ccc      IF (ierr .NE. NF_NOERR) THEN
ccc         PRINT*, "condsurf: Le champ <tsol> est absent"
ccc         CALL abort
ccc      ENDIF
ccc#ifdef NC_DOUBLE
ccc      ierr = NF_GET_VARA_DOUBLE(nid, nvarid,deb,epa,cpl_sst)
ccc#else
ccc      ierr = NF_GET_VARA_REAL(nid, nvarid,deb,epa,cpl_sst)
ccc#endif
ccc      IF (ierr .NE. NF_NOERR) THEN
ccc         PRINT*, "condsurf: Lecture echouee pour <tsol>"
ccc         CALL abort
ccc      ENDIF
ccc      ierr = NF_INQ_VARID (nid, "sicf", nvarid)
ccc      IF (ierr .NE. NF_NOERR) THEN
ccc         PRINT*, "condsurf: Le champ <sicf> est absent"
ccc         CALL abort
ccc      ENDIF
ccc#ifdef NC_DOUBLE
ccc      ierr = NF_GET_VARA_DOUBLE(nid, nvarid,deb,epa,cpl_sic)
ccc#else
ccc      ierr = NF_GET_VARA_REAL(nid, nvarid,deb,epa,cpl_sic)
ccc#endif
ccc      IF (ierr .NE. NF_NOERR) THEN
ccc         PRINT*, "condsurf: Lecture echouee pour <sicf>"
ccc         CALL abort
ccc      ENDIF
ccc         DO i = 1, iim-1 ! un seul point pour le pole nord
ccc            cpl_sst(i,1) = cpl_sst(iim,1)
ccc            cpl_sic(i,1) = cpl_sic(iim,1)
ccc         ENDDO
ccc         DO i = 2, iim ! un seul point pour le pole sud
ccc            cpl_sst(i,jjm+1) = cpl_sst(1,jjm+1)
ccc            cpl_sic(i,jjm+1) = cpl_sic(1,jjm+1)
ccc         ENDDO
cccc
ccc         ig = 1
ccc         IF (pctsrf(ig,is_oce).GT.epsfra .OR.
ccc     .       pctsrf(ig,is_sic).GT.epsfra) THEN
ccc            pctsrf(ig,is_oce) = pctsrf(ig,is_oce)
ccc     .                        - (cpl_sic(1,1)-pctsrf(ig,is_sic))
ccc            pctsrf(ig,is_sic) = cpl_sic(1,1)
ccc            lmt_sst(ig) = cpl_sst(1,1)
ccc         ENDIF
ccc         DO j = 2, jjm
ccc         DO i = 1, iim
ccc         ig = ig + 1
ccc         IF (pctsrf(ig,is_oce).GT.epsfra .OR.
ccc     .       pctsrf(ig,is_sic).GT.epsfra) THEN
ccc           pctsrf(ig,is_oce) = pctsrf(ig,is_oce)
ccc     .                       - (cpl_sic(i,j)-pctsrf(ig,is_sic))
ccc           pctsrf(ig,is_sic) = cpl_sic(i,j)
ccc           lmt_sst(ig) = cpl_sst(i,j)
ccc         ENDIF
ccc         ENDDO
ccc         ENDDO
ccc         ig = ig + 1
ccc         IF (pctsrf(ig,is_oce).GT.epsfra .OR.
ccc     .       pctsrf(ig,is_sic).GT.epsfra) THEN
ccc            pctsrf(ig,is_oce) = pctsrf(ig,is_oce)
ccc     .                        - (cpl_sic(1,jjm+1)-pctsrf(ig,is_sic))
ccc            pctsrf(ig,is_sic) = cpl_sic(1,jjm+1)
ccc            lmt_sst(ig) = cpl_sst(1,jjm+1)
ccc         ENDIF
ccc      ierr = NF_CLOSE(nid)
c special f_modele_c
c
      PRINT*, 'SST, ALB, RUG, etc. sont lus pour jour: ', jour
c
      RETURN
      END
      SUBROUTINE lireqsol(jour, lmt_qsol)
      IMPLICIT none
c
#include "netcdf.inc"
c
#include "dimensions.h"
#include "dimphy.h"
#include "indicesol.h"
#include "temps.h"
#include "clesphys.h"
c
      INTEGER jour
      REAL lmt_qsol(klon)
c
c Variables locales:
      INTEGER ig, i, j, ierr, n, nb, n_ok
      REAL qsol(iim,jjm+1)
      INTEGER deb(3), epa(3)
      INTEGER nid, varid
c
      REAL shijian(360)
c
      IF (jour.LT.0 .OR. jour.GT.(360-1)) THEN
         PRINT*,'Le jour demande est faux dans lireqsol: ', jour
         CALL ABORT
      ENDIF
c
c Ouvrir le fichier en format NetCDF:
c
      ierr = NF_OPEN ("qsol_climato.nc", NF_NOWRITE,nid)
      IF (ierr.NE.NF_NOERR) THEN
        PRINT*, 'Pb d''ouverture du fichier qsol_climato'
        CALL abort
      ENDIF
c
      ierr = NF_INQ_DIMID(nid,"time",varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "lireqsol: Probleme pour avoir DIMID de time"
         CALL abort
      ENDIF
      ierr = NF_INQ_DIMLEN(nid,varid,nb)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "lireqsol: Probleme pour avoir DIMLEN de time"
         CALL abort
      ENDIF
c
      ierr = NF_INQ_VARID(nid,"time", varid)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour avoir VARID de time"
         CALL abort
      ENDIF
      ierr = NF_GET_VARA_REAL(nid,varid,1,nb,shijian)
      IF (ierr.NE.NF_NOERR) THEN
         PRINT*, "Probleme pour extraire variable time"
         CALL abort
      ENDIF
c
      n_ok = 0
      DO n = 1, nb
         IF (NINT(shijian(n)).EQ.(jour+1)) n_ok = n
      ENDDO
      IF (n_ok.EQ.0) THEN
         PRINT*, 'lireqsol: Le jour demande est absent du fichier'
         CALL abort
      ENDIF
c
      deb(1) = 1
      deb(2) = 1
      deb(3) = n_ok
      epa(1) = iim
      epa(2) = jjm + 1
      epa(3) = 1
      ierr = NF_INQ_VARID (nid, "qsol", varid)
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "lireqsol: Le champ <qsol> est absent"
         CALL abort
      ENDIF
#ifdef NC_DOUBLE
      ierr = NF_GET_VARA_DOUBLE(nid, varid,deb,epa,qsol)
#else
      ierr = NF_GET_VARA_REAL(nid, varid,deb,epa,qsol)
#endif
      IF (ierr .NE. NF_NOERR) THEN
         PRINT*, "lireqsol: Lecture echouee pour <qsol>"
         CALL abort
      ENDIF
         DO i = 1, iim-1 ! un seul point pour le pole nord
            qsol(i,1) = qsol(iim,1)
         ENDDO
         DO i = 2, iim ! un seul point pour le pole sud
            qsol(i,jjm+1) = qsol(1,jjm+1)
         ENDDO
c
         ig = 1
         lmt_qsol(ig) = qsol(1,1)
         DO j = 2, jjm
         DO i = 1, iim
         ig = ig + 1
         lmt_qsol(ig) = qsol(i,j)
         ENDDO
         ENDDO
         ig = ig + 1
         lmt_qsol(ig) = qsol(1,jjm+1)
      ierr = NF_CLOSE(nid)
c
      PRINT*, 'qsol_climato est lue pour jour ', jour
c
      RETURN
      END
