      SUBROUTINE physiq (ecritphy,nlon,nlev,nqmax  ,
     .            debut,lafin,rjourvrai,rjour_ecri,gmtime,pdtphys,
     .            paprs,pplay,pphi,pphis,paire,presnivs,clesphy0,
     .            u,v,t,qx,
ccc     .            d_t_dyn, d_q_dyn,
     .            omega,
     .            d_u, d_v, d_t, d_qx, d_ps)
ccc      USE ioipsl
      IMPLICIT none
c perturb
c      REAL ran
c      EXTERNAL ran
c perturb
c======================================================================
c
c Auteur(s) Z.X. Li (LMD/CNRS) date: 19930818
c
c Objet: Moniteur general de la physique du modele

c======================================================================
c    modif   ( P. Le Van ,  12/10/98 )
c
c  Arguments:
c
c nlon----input-I-nombre de points horizontaux
c nlev----input-I-nombre de couches verticales
c nqmax---input-I-nombre de traceurs (y compris vapeur d'eau) = 1
c debut---input-L-variable logique indiquant le premier passage
c lafin---input-L-variable logique indiquant le dernier passage
c rjour---input-R-numero du jour de l'experience
c gmtime--input-R-temps universel dans la journee (0 a 86400 s)
c pdtphys-input-R-pas d'integration pour la physique (seconde)
c paprs---input-R-pression pour chaque inter-couche (en Pa)
c pplay---input-R-pression pour le mileu de chaque couche (en Pa)
c pphi----input-R-geopotentiel de chaque couche (g z) (reference sol)
c pphis---input-R-geopotentiel du sol
c paire---input-R-aire de chaque maille
c presnivs-input_R_pressions approximat. des milieux couches ( en PA)
c u-------input-R-vitesse dans la direction X (de O a E) en m/s
c v-------input-R-vitesse Y (de S a N) en m/s
c t-------input-R-temperature (K)
c qx------input-R-humidite specifique (kg/kg) et d'autres traceurs
c d_t_dyn-input-R-tendance dynamique pour "t" (K/s)
c d_q_dyn-input-R-tendance dynamique pour "q" (kg/kg/s)
c omega---input-R-vitesse verticale en Pa/s
c
c d_u-----output-R-tendance physique de "u" (m/s/s)
c d_v-----output-R-tendance physique de "v" (m/s/s)
c d_t-----output-R-tendance physique de "t" (K/s)
c d_qx----output-R-tendance physique de "qx" (kg/kg/s)
c d_ps----output-R-tendance physique de la pression au sol
c======================================================================
#include "dimensions.h"
#include "dimphy.h"
#include "indicesol.h"
#include "dimsoil.h"
#include "clesphys.h"
c======================================================================
      LOGICAL check ! Verifier la conservation du modele en eau
      PARAMETER (check=.FALSE.)
      LOGICAL ok_stratus ! Ajouter artificiellement les stratus
      PARAMETER (ok_stratus=.FALSE.)
c======================================================================
c Parametres lies au coupleur OASIS:
#include "oasis.h"
      INTEGER npas, nexca, itimestep
ccc      PARAMETER (npas=240)
ccc      PARAMETER (npas=1440)
      PARAMETER (npas=17280)
      PARAMETER (nexca=6)
      PARAMETER (itimestep=1800)
ccc      EXTERNAL fromcpl, intocpl, inicma
      REAL cpl_sst(iim,jjm+1), cpl_sic(iim,jjm+1)
      REAL cpl_alb_sst(iim,jjm+1), cpl_alb_sic(iim,jjm+1)
c======================================================================
c ok_slab indique l'utilisation du modele oceanique "slab ocean",
c il faut bien sur s'assurer que le bilan energetique de reference
c a la surface de l'ocean est bien present dans le fichier des
c conditions aux limites
c
      LOGICAL ok_slab
      PARAMETER (ok_slab=.FALSE.)
      REAL zz
      REAL cyang, cbing
      PARAMETER (cyang=50.0 * 4.228e+06) ! J/(m2 K)
      PARAMETER (cbing=0.334e+05) ! J/kg
      INTEGER slab_pas
      PARAMETER (slab_pas=48)
      REAL slab_bils(klon)
      SAVE slab_bils
c
c======================================================================
c Clef controlant l'activation du cycle diurne:
ccc      LOGICAL cycle_diurne
ccc      PARAMETER (cycle_diurne=.FALSE.)
c======================================================================
c Modele thermique du sol, a activer pour le cycle diurne:
ccc      LOGICAL soil_model
ccc      PARAMETER (soil_model=.FALSE.)
      REAL soilcap(klon,nbsrf), soilflux(klon,nbsrf)
      SAVE soilcap, soilflux
c======================================================================
c Dans les versions precedentes, l'eau liquide nuageuse utilisee dans
c le calcul du rayonnement est celle apres la precipitation des nuages.
c Si cette cle new_oliq est activee, ce sera une valeur moyenne entre
c la condensation et la precipitation. Cette cle augmente les impacts
c radiatifs des nuages.
ccc      LOGICAL new_oliq
ccc      PARAMETER (new_oliq=.FALSE.)
c======================================================================
c Clefs controlant deux parametrisations de l'orographie:
cc      LOGICAL ok_orodr
ccc      PARAMETER (ok_orodr=.FALSE.)
ccc      LOGICAL ok_orolf
ccc      PARAMETER (ok_orolf=.FALSE.)
c======================================================================
      LOGICAL ok_journe ! sortir le fichier journalier
      PARAMETER (ok_journe=.TRUE.)
c
      LOGICAL ok_mensuel ! sortir le fichier journalier
      PARAMETER (ok_mensuel=.FALSE.)
c
      LOGICAL ok_instan ! sortir le fichier instantane
      PARAMETER (ok_instan=.FALSE.)
c
      LOGICAL ok_region ! sortir le fichier regional
      PARAMETER (ok_region=.FALSE.)
c======================================================================
      LOGICAL ok_perpet ! en mode perpetuel
      PARAMETER (ok_perpet=.TRUE.)
      INTEGER jour_perpet
      PARAMETER (jour_perpet=15)
      REAL qsol_perpet(klon)
      SAVE qsol_perpet
c======================================================================
c
      INTEGER ivap          ! indice de traceurs pour vapeur d'eau
      PARAMETER (ivap=1)
      INTEGER iliq          ! indice de traceurs pour eau liquide
      PARAMETER (iliq=2)
c
      INTEGER nvm           ! nombre de vegetations
      PARAMETER (nvm=8)
      REAL veget(klon,nvm)  ! couverture vegetale
      SAVE veget
c
c Variables argument:
c
      REAL ecritphy
c
      INTEGER nlon
      INTEGER nlev
      INTEGER nqmax
      REAL rjourvrai, rjour_ecri
      REAL gmtime
      REAL pdtphys
      LOGICAL debut, lafin
      REAL paprs(klon,klev+1)
      REAL pplay(klon,klev)
      REAL pphi(klon,klev)
      REAL pphis(klon)
      REAL paire(klon)
      REAL presnivs(klev)

      REAL u(klon,klev)
      REAL v(klon,klev)
      REAL t(klon,klev)
      REAL qx(klon,klev,nqmax)

      REAL t_ancien(klon,klev), q_ancien(klon,klev)
      SAVE t_ancien, q_ancien
      LOGICAL ancien_ok
      SAVE ancien_ok

      REAL d_t_dyn(klon,klev)
      REAL d_q_dyn(klon,klev)

      REAL omega(klon,klev)

      REAL d_u(klon,klev)
      REAL d_v(klon,klev)
      REAL d_t(klon,klev)
      REAL d_qx(klon,klev,nqmax)
      REAL d_ps(klon)

      INTEGER        longcles
      PARAMETER    ( longcles = 20 )
      REAL clesphy0( longcles      )
c
c Variables quasi-arguments
c
      REAL xjour
      SAVE xjour
c
c
c Variables propres a la physique
c
      REAL dtime
      SAVE dtime                  ! pas temporel de la physique
c
      INTEGER radpas
      SAVE radpas                 ! frequence d'appel rayonnement
c
      REAL radsol(klon)
      SAVE radsol                 ! bilan radiatif au sol
c
      REAL rlat(klon)
      SAVE rlat                   ! latitude pour chaque point
c
      REAL rlon(klon)
      SAVE rlon                   ! longitude pour chaque point
c
cc      INTEGER iflag_con
cc      SAVE iflag_con              ! indicateur de la convection
c
      INTEGER itap
      SAVE itap                   ! compteur pour la physique
c
      REAL co2_ppm,co2_bis
      SAVE co2_ppm,co2_bis        ! concentration du CO2
c
      REAL solaire
      SAVE solaire                ! constante solaire
c
      REAL ftsol(klon,nbsrf)
      SAVE ftsol                  ! temperature du sol
c
      REAL ftsoil(klon,nsoilmx,nbsrf)
      SAVE ftsoil                 ! temperature dans le sol
c
      REAL tslab(klon)
      SAVE tslab                  ! Temperature du slab-ocean
c
      REAL seaice(klon)
      SAVE seaice                 ! glace de mer (kg/m2)
c
      REAL fqsol(klon,nbsrf)
      SAVE fqsol                  ! humidite du sol
c
      REAL fsnow(klon,nbsrf)
      SAVE fsnow                  ! epaisseur neigeuse
c
      REAL rugmer(klon)
      SAVE rugmer                 ! longeur de rugosite sur mer (m)
c
c  Parametres de l'Orographie a l'Echelle Sous-Maille (OESM):
c
      REAL zmea(klon)
      SAVE zmea                   ! orographie moyenne
c
      REAL zstd(klon)
      SAVE zstd                   ! deviation standard de l'OESM
c
      REAL zsig(klon)
      SAVE zsig                   ! pente de l'OESM
c
      REAL zgam(klon)
      save zgam                   ! anisotropie de l'OESM
c
      REAL zthe(klon)
      SAVE zthe                   ! orientation de l'OESM
c
      REAL zpic(klon)
      SAVE zpic                   ! Maximum de l'OESM
c
      REAL zval(klon)
      SAVE zval                   ! Minimum de l'OESM
c
      REAL rugoro(klon)
      SAVE rugoro                 ! longueur de rugosite de l'OESM
c
      REAL zulow(klon),zvlow(klon),zustr(klon), zvstr(klon)
c
      REAL zuthe(klon),zvthe(klon)
      SAVE zuthe
      SAVE zvthe
      INTEGER igwd,igwdim,idx(klon),itest(klon)
c
      REAL agesno(klon)
      SAVE agesno                 ! age de la neige
c
      REAL alb_neig(klon)
      SAVE alb_neig               ! albedo de la neige
c
c Variables locales:
c
      REAL cdragh(klon) ! drag coefficient pour T and Q
      REAL cdragm(klon) ! drag coefficient pour vent
c
      REAL rain_fall(klon) ! pluie
      REAL snow_fall(klon) ! neige
      REAL evap(klon), devap(klon) ! evaporation et sa derivee
      REAL sens(klon), dsens(klon) ! chaleur sensible et sa derivee
      REAL bils(klon) ! bilan de chaleur au sol
      REAL fluxg(klon)
      REAL fluxo(klon)
      REAL fder(klon) ! Derive de flux (sensible et latente) 
      REAL ruis(klon) ! ruissellement
      REAL ve(klon) ! integr. verticale du transport meri. de l'energie
      REAL vq(klon) ! integr. verticale du transport meri. de l'eau
      REAL ue(klon) ! integr. verticale du transport zonal de l'energie
      REAL uq(klon) ! integr. verticale du transport zonal de l'eau
c
      REAL frugs(klon,nbsrf) ! longueur de rugosite
      REAL zxrugs(klon) ! longueur de rugosite
c
c Conditions aux limites
c
      INTEGER julien
      INTEGER idayvrai
      SAVE idayvrai
c
      INTEGER lmt_pas
      SAVE lmt_pas                ! frequence de mise a jour
      REAL pctsrf(klon,nbsrf)
      SAVE pctsrf                 ! sous-fraction du sol
      REAL lmt_sst(klon)
      SAVE lmt_sst                ! temperature de la surface ocean
      REAL lmt_bils(klon)
      SAVE lmt_bils               ! bilan de chaleur au sol
      REAL lmt_alb(klon)
      SAVE lmt_alb                ! temperature de la surface ocean
      REAL lmt_rug(klon)
      SAVE lmt_rug                ! longueur de rugosite
      REAL alb_eau(klon)
      SAVE alb_eau                ! albedo sur l'ocean
      REAL albsol(klon)
      SAVE albsol                 ! albedo du sol total
      REAL wo(klon,klev)
      SAVE wo                     ! ozone
c======================================================================
c
c Declaration des procedures appelees
c
      EXTERNAL angle     ! calculer angle zenithal du soleil
      EXTERNAL alboc     ! calculer l'albedo sur ocean
      EXTERNAL albsno    ! calculer albedo sur neige
      EXTERNAL ajsec     ! ajustement sec
      EXTERNAL clmain    ! couche limite
      EXTERNAL condsurf  ! lire les conditions aux limites
      EXTERNAL conlmd    ! convection (schema LMD)
      EXTERNAL fisrtilp  ! schema de condensation a grande echelle (pluie)
      EXTERNAL hgardfou  ! verifier les temperatures
      EXTERNAL hydrol    ! hydrologie du sol
      EXTERNAL nuage     ! calculer les proprietes radiatives
      EXTERNAL o3cm      ! initialiser l'ozone
      EXTERNAL orbite    ! calculer l'orbite terrestre
      EXTERNAL ozonecm   ! prescrire l'ozone
      EXTERNAL phyetat0  ! lire l'etat initial de la physique
      EXTERNAL phyredem  ! ecrire l'etat de redemarrage de la physique
      EXTERNAL radlwsw   ! rayonnements solaire et infrarouge
      EXTERNAL suphec    ! initialiser certaines constantes
      EXTERNAL transp    ! transport total de l'eau et de l'energie
c
c Variables locales
c
      REAL dialiq(klon,klev)  ! eau liquide nuageuse
      REAL diafra(klon,klev)  ! fraction nuageuse
      REAL cldliq(klon,klev)  ! eau liquide nuageuse
      REAL cldfra(klon,klev)  ! fraction nuageuse
      REAL cldtau(klon,klev)  ! epaisseur optique
      REAL cldemi(klon,klev)  ! emissivite infrarouge
c
      REAL fluxq(klon,klev)   ! flux turbulent d'humidite
      REAL fluxt(klon,klev)   ! flux turbulent de chaleur
      REAL fluxu(klon,klev)   ! flux turbulent de vitesse u
      REAL fluxv(klon,klev)   ! flux turbulent de vitesse v
c
      REAL heat(klon,klev)    ! chauffage solaire
      REAL heat0(klon,klev)   ! chauffage solaire ciel clair
      REAL cool(klon,klev)    ! refroidissement infrarouge
      REAL cool0(klon,klev)   ! refroidissement infrarouge ciel clair
      REAL topsw(klon), toplw(klon)
      REAL topsw0(klon), toplw0(klon)
      REAL albpla(klon)
      REAL solsw_up(klon), solsw_dn(klon)
      REAL sollw_up(klon), sollw_dn(klon)
c Le rayonnement n'est pas calcule tous les pas, il faut donc
c                      sauvegarder les sorties du rayonnement
      SAVE heat,cool,albpla,topsw,toplw
      SAVE topsw0,toplw0, heat0, cool0
      SAVE solsw_up, solsw_dn, sollw_up, sollw_dn
      INTEGER itaprad
      SAVE itaprad
c
      REAL conv_q(klon,klev) ! convergence de l'humidite (kg/kg/s)
      REAL conv_t(klon,klev) ! convergence de la temperature(K/s)
c
      REAL cldl(klon),cldm(klon),cldh(klon) !nuages bas, moyen et haut
      REAL cldt(klon),cldq(klon) !nuage total, eau liquide integree
c
      REAL zx_alb_lic, zx_alb_oce, zx_alb_ter, zx_alb_sic
      REAL zxtsol(klon), zxqsol(klon), zxsnow(klon)
c
      REAL dist, rmu0(klon), fract(klon)
      REAL zdtime, zlongi
      REAL frachomo(klon)
c
      CHARACTER*2 str2
      CHARACTER*2 iqn
c
      REAL qcheck, cptcheck 
      REAL z_avant(klon), z_apres(klon), z_factor(klon)
      LOGICAL zx_ajustq
c
      REAL za, zb
      REAL zx_t, zx_qs, zdelta, zcor, zfra, zlvdcp, zlsdcp
      INTEGER i, k, iq, ig, j, nsrf
      REAL t_coup
      PARAMETER (t_coup=234.0)
c
      REAL zphi(klon,klev)
c
c Variables du changement
c
c con: convection
c lsc: condensation a grande echelle (Large-Scale-Condensation)
c ajs: ajustement sec
c eva: evaporation de l'eau liquide nuageuse
c vdf: couche limite (Vertical DiFfusion)
      REAL d_t_con(klon,klev),d_q_con(klon,klev)
      REAL d_u_con(klon,klev),d_v_con(klon,klev)
      REAL d_t_lsc(klon,klev),d_q_lsc(klon,klev),d_ql_lsc(klon,klev)
      REAL d_t_ajs(klon,klev), d_q_ajs(klon,klev)
      REAL d_t_eva(klon,klev),d_q_eva(klon,klev)
      REAL rneb(klon,klev)
c
      REAL pmfu(klon,klev), pmfd(klon,klev)
      REAL pen_u(klon,klev), pen_d(klon,klev)
      REAL pde_u(klon,klev), pde_d(klon,klev)
      INTEGER kcbot(klon), kctop(klon), kdtop(klon)
      REAL pmflxr(klon,klev+1), pmflxs(klon,klev+1)
c
      INTEGER ibas_con(klon), itop_con(klon)
      REAL rain_con(klon), rain_lsc(klon)
      REAL snow_con(klon), snow_lsc(klon)
      REAL d_ts(klon,nbsrf)
c
      REAL d_u_vdf(klon,klev), d_v_vdf(klon,klev)
      REAL d_t_vdf(klon,klev), d_q_vdf(klon,klev)
c
      REAL d_u_oro(klon,klev), d_v_oro(klon,klev)
      REAL d_t_oro(klon,klev)
      REAL d_u_lif(klon,klev), d_v_lif(klon,klev)
      REAL d_t_lif(klon,klev)
c
c Variables liees a l'ecriture de la bande histoire physique
c
      REAL oas_sols(klon), z_sols(iim,jjm+1)
      SAVE oas_sols
      REAL oas_nsol(klon), z_nsol(iim,jjm+1)
      SAVE oas_nsol
      REAL oas_rain(klon), z_rain(iim,jjm+1)
      SAVE oas_rain
      REAL oas_snow(klon), z_snow(iim,jjm+1)
      SAVE oas_snow
      REAL oas_evap(klon), z_evap(iim,jjm+1), z_watf(iim,jjm+1)
      SAVE oas_evap
      REAL oas_ruis(klon), z_ruis(iim,jjm+1)
      SAVE oas_ruis
      REAL oas_tsol(klon), z_tsol(iim,jjm+1)
      SAVE oas_tsol
      REAL oas_fder(klon), z_fder(iim,jjm+1)
      SAVE oas_fder
      REAL oas_albe(klon), z_albe(iim,jjm+1)
      SAVE oas_albe
      REAL oas_taux(klon), z_taux(iim,jjm+1)
      SAVE oas_taux
      REAL oas_tauy(klon), z_tauy(iim,jjm+1)
      SAVE oas_tauy
      REAL oas_ruisoce(klon), z_ruisoce(iim,jjm+1)
      SAVE oas_ruisoce
      REAL oas_ruisriv(klon), z_ruisriv(iim,jjm+1)
      SAVE oas_ruisriv
c
c Variables locales pour effectuer les appels en serie
c
      REAL t_seri(klon,klev), q_seri(klon,klev)
      REAL ql_seri(klon,klev)
      REAL u_seri(klon,klev), v_seri(klon,klev)
c
      REAL tr_seri(klon,klev,nbtr)
      REAL d_tr(klon,klev,nbtr)
      REAL source_tr(klon,nbtr)
      REAL taupuits(klev,nbtr)

      REAL zx_rh(klon,klev)

      INTEGER        length
      PARAMETER    ( length = 100 )
      REAL tabcntr0( length       )
c
      INTEGER ndex3d(iim*(jjm+1)*klev), ndex2d(iim*(jjm+1))
      REAL zx_tmp_fi2d(klon)
      REAL zx_tmp_2d(iim,jjm+1), zx_tmp_3d(iim,jjm+1,klev)
      REAL zx_lon(iim,jjm+1), zx_lat(iim,jjm+1)
c
      INTEGER nhori, nvert
      REAL zsto, zout, zjulian
      REAL zstobis
c
      REAL t2m(klon), q2m(klon),  u10m(klon), v10m(klon)
      REAL slp(klon), zpr
c
      INTEGER lstd
      PARAMETER (lstd=15)
      REAL plvl(lstd)
      REAL ulvl(klon,lstd),vlvl(klon,lstd),tlvl(klon,lstd)
      REAL glvl(klon,lstd),qlvl(klon,lstd)
      INTEGER iwork1(klon),iwork2(klon)
      INTEGER ndex3d_std(iim*(jjm+1),lstd)
      REAL tmp3d_std(iim*(jjm+1),lstd)
c
c Declaration des constantes et des fonctions thermodynamiques
c
#include "YOMCST.h"
#include "YOETHF.h"
#include "FCTTRE.h"
c
      DATA (plvl(k),k=1,lstd) /1000, 925, 850, 700, 600, 500, 400,
     .                         300, 250, 200, 150, 100, 70, 50, 10/
c======================================================================
      IF (nqmax .LT. 2) THEN
         PRINT*, 'eaux vapeur et liquide sont indispensables'
         CALL ABORT
      ENDIF
      IF (debut) THEN
         CALL suphec ! initialiser constantes et parametres phys.
      ENDIF
c======================================================================
      xjour = rjourvrai
c
c Si c'est le debut, il faut initialiser plusieurs choses
c          ********
c
       IF (debut) THEN
c
 
         IF (ok_oasis) THEN
            PRINT*, "Attentions! les parametres suivants sont fixes:"
            PRINT *,'***********************************************'
            PRINT*, "npas, nexca, itimestep=", npas, nexca, itimestep
            PRINT*, "Changer-les manuellement s il le faut"
            PRINT *,'***********************************************'
            CALL inicma( npas, nexca, itimestep)
         ENDIF
c
         IF (ok_slab) THEN
            PRINT*, '************************'
            PRINT*, 'SLAB OCEAN est active, prenez precautions !'
            PRINT*, '************************'
         ENDIF
c
         IF (ok_perpet) THEN
            PRINT*, '************************'
            PRINT*, 'Run Perpetuel pour jour: ', jour_perpet
            PRINT*, '************************'
         ENDIF
c
         DO k = 2, nvm          ! pas de vegetation
            DO i = 1, klon
               veget(i,k) = 0.0
            ENDDO
         ENDDO
         DO i = 1, klon
            veget(i,1) = 1.0    ! il n'y a que du desert
         ENDDO
         PRINT*, 'Pas de vegetation; desert partout'
c
c Initialiser les compteurs:
c

         itap    = 0
         itaprad = 0
c
         CALL phyetat0 ("startphy.nc",dtime,co2_ppm,solaire,
     .         rlat,rlon,ftsol,ftsoil,tslab,seaice,fqsol,fsnow,
     .        radsol,rugmer,agesno,clesphy0,
     .       zmea,zstd,zsig,zgam,zthe,zpic,zval,rugoro,tabcntr0,
     .       t_ancien, q_ancien, ancien_ok )
c
         IF (ok_perpet) THEN
            CALL lireqsol(jour_perpet,qsol_perpet)
         ENDIF

         co2_bis = co2_ppm
c
         radpas = NINT( 86400./dtime/nbapp_rad)

c
         CALL printflag( tabcntr0,radpas,ok_slab,ok_oasis ,ok_journe,
     ,                    ok_instan, ok_region )
c
         IF (ABS(dtime-pdtphys).GT.0.001) THEN
            PRINT*, 'Pas physique n est pas correcte',dtime,pdtphys
            CALL abort
         ENDIF
         IF (nlon .NE. klon) THEN
            PRINT*, 'nlon et klon ne sont pas coherents', nlon, klon
            CALL abort
         ENDIF
         IF (nlev .NE. klev) THEN
            PRINT*, 'nlev et klev ne sont pas coherents', nlev, klev
            CALL abort
         ENDIF
c
         IF (dtime*FLOAT(radpas).GT.21600..AND.cycle_diurne) THEN 
          PRINT*, 'Nbre d appels au rayonnement insuffisant'
          PRINT*, "Au minimum 4 appels par jour si cycle diurne"
          CALL abort
         ENDIF
         PRINT*, "Clef pour la convection, iflag_con=", iflag_con
c
         IF (ok_orodr) THEN
         DO i=1,klon
         rugoro(i) = MAX(1.0e-05, zstd(i)*zsig(i)/2.0)
         ENDDO
         CALL SUGWD(klon,klev,paprs,pplay)
         DO i=1,klon
         zuthe(i)=0.
         zvthe(i)=0.
         if(zstd(i).gt.10.)then
           zuthe(i)=(1.-zgam(i))*cos(zthe(i))
           zvthe(i)=(1.-zgam(i))*sin(zthe(i))
         endif
         ENDDO
         ENDIF
c
         lmt_pas = NINT(86400./dtime * 1.0)   ! tous les jours
         PRINT*,'La frequence de lecture surface est de ', lmt_pas
c
c
c Prescrire l'ozone dans l'atmosphere
c
c
cc         DO i = 1, klon
cc         DO k = 1, klev
cc            CALL o3cm (paprs(i,k)/100.,paprs(i,k+1)/100., wo(i,k),20)
cc         ENDDO
cc         ENDDO
c
         IF (ok_oasis) THEN
         DO i = 1, klon
           oas_sols(i) = 0.0
           oas_nsol(i) = 0.0
           oas_rain(i) = 0.0
           oas_snow(i) = 0.0
           oas_evap(i) = 0.0
           oas_ruis(i) = 0.0
           oas_tsol(i) = 0.0
           oas_fder(i) = 0.0
           oas_albe(i) = 0.0
           oas_taux(i) = 0.0
           oas_tauy(i) = 0.0
         ENDDO
         ENDIF
c
         IF (ok_slab) THEN
         DO i = 1, klon
            slab_bils(i) = 0.0
         ENDDO
         ENDIF
c
      ENDIF
c
c   ****************     Fin  de   IF ( debut  )   ***************
c
c
c Mettre a zero des variables de sortie (pour securite)
c
      DO i = 1, klon
         d_ps(i) = 0.0
      ENDDO
      DO k = 1, klev
      DO i = 1, klon
         d_t(i,k) = 0.0
         d_u(i,k) = 0.0
         d_v(i,k) = 0.0
      ENDDO
      ENDDO
      DO iq = 1, nqmax
      DO k = 1, klev
      DO i = 1, klon
         d_qx(i,k,iq) = 0.0
      ENDDO
      ENDDO
      ENDDO
c
c Ne pas affecter les valeurs entrees de u, v, h, et q
c
      DO k = 1, klev
      DO i = 1, klon
         t_seri(i,k)  = t(i,k)
         u_seri(i,k)  = u(i,k)
         v_seri(i,k)  = v(i,k)
         q_seri(i,k)  = qx(i,k,ivap)
         ql_seri(i,k) = qx(i,k,iliq)
      ENDDO
      ENDDO
      IF (nqmax.GE.3) THEN
      DO iq = 3, nqmax
      DO  k = 1, klev
      DO  i = 1, klon
         tr_seri(i,k,iq-2) = qx(i,k,iq)
      ENDDO
      ENDDO
      ENDDO
      ELSE
      DO k = 1, klev
      DO i = 1, klon
         tr_seri(i,k,1) = 0.0
      ENDDO
      ENDDO
      ENDIF
c
c Diagnostiquer la tendance dynamique
c
      IF (ancien_ok) THEN
         DO k = 1, klev
         DO i = 1, klon
            d_t_dyn(i,k) = (t_seri(i,k)-t_ancien(i,k))/dtime
            d_q_dyn(i,k) = (q_seri(i,k)-q_ancien(i,k))/dtime
         ENDDO
         ENDDO
      ELSE
         DO k = 1, klev
         DO i = 1, klon
            d_t_dyn(i,k) = 0.0
            d_q_dyn(i,k) = 0.0
         ENDDO
         ENDDO
         ancien_ok = .TRUE.
      ENDIF
c
c Ajouter le geopotentiel du sol:
c
      DO k = 1, klev
      DO i = 1, klon
         zphi(i,k) = pphi(i,k) + pphis(i)
      ENDDO
      ENDDO
c
c Verifier les temperatures
c

      CALL hgardfou(t_seri,ftsol,'debutphy')
c
c Incrementer le compteur de la physique
c
      itap   = itap + 1
      julien = MOD(NINT(xjour),360)
c
      IF (ok_perpet) THEN
         julien = jour_perpet
         DO nsrf = 1, nbsrf
         DO i = 1, klon
            fqsol(i,nsrf) = qsol_perpet(i)
         ENDDO
         ENDDO
      ENDIF
c
c Mettre en action les conditions aux limites (albedo, sst, etc.).
c Prescrire l'ozone et calculer l'albedo sur l'ocean.
c
      IF (MOD(itap-1,lmt_pas) .EQ. 0) THEN
         idayvrai = NINT(xjour)
         PRINT *,' PHYS cond  julien ',julien,idayvrai
         CALL condsurf(julien,idayvrai, pctsrf ,
     .                  lmt_sst,lmt_alb,lmt_rug,lmt_bils  )
         CALL ozonecm( FLOAT(julien), rlat, paprs, wo)
      ENDIF
cccccccccc
      IF (ok_oasis .AND. MOD(itap-1,nexca).EQ.0) THEN
C
         CALL fromcpl(itap,(jjm+1)*iim,
     .        cpl_sst,cpl_sic,cpl_alb_sst,cpl_alb_sic)
         DO i = 1, iim-1 ! un seul point pour le pole nord
            cpl_sst(i,1) = cpl_sst(iim,1)
            cpl_sic(i,1) = cpl_sic(iim,1)
            cpl_alb_sst(i,1) = cpl_alb_sst(iim,1)
            cpl_alb_sic(i,1) = cpl_alb_sic(iim,1)
         ENDDO
         DO i = 2, iim ! un seul point pour le pole sud
            cpl_sst(i,jjm+1) = cpl_sst(1,jjm+1)
            cpl_sic(i,jjm+1) = cpl_sic(1,jjm+1)
            cpl_alb_sst(i,jjm+1) = cpl_alb_sst(1,jjm+1)
            cpl_alb_sic(i,jjm+1) = cpl_alb_sic(1,jjm+1)
         ENDDO
c
         ig = 1
         IF (pctsrf(ig,is_oce).GT.epsfra .OR.
     .       pctsrf(ig,is_sic).GT.epsfra) THEN
            pctsrf(ig,is_oce) = pctsrf(ig,is_oce)
     .                        - (cpl_sic(1,1)-pctsrf(ig,is_sic))
            pctsrf(ig,is_sic) = cpl_sic(1,1)
            lmt_sst(ig) = cpl_sst(1,1)
         ENDIF
         DO j = 2, jjm
         DO i = 1, iim
         ig = ig + 1
         IF (pctsrf(ig,is_oce).GT.epsfra .OR.
     .       pctsrf(ig,is_sic).GT.epsfra) THEN
           pctsrf(ig,is_oce) = pctsrf(ig,is_oce) 
     .                       - (cpl_sic(i,j)-pctsrf(ig,is_sic))
           pctsrf(ig,is_sic) = cpl_sic(i,j)
           lmt_sst(ig) = cpl_sst(i,j)
         ENDIF
         ENDDO
         ENDDO
         ig = ig + 1
         IF (pctsrf(ig,is_oce).GT.epsfra .OR.
     .       pctsrf(ig,is_sic).GT.epsfra) THEN
            pctsrf(ig,is_oce) = pctsrf(ig,is_oce)
     .                        - (cpl_sic(1,jjm+1)-pctsrf(ig,is_sic))
            pctsrf(ig,is_sic) = cpl_sic(1,jjm+1)
            lmt_sst(ig) = cpl_sst(1,jjm+1)
         ENDIF
c
      ENDIF ! ok_oasis
cccccccccc
c
      IF (ok_slab) THEN
         DO i = 1, klon
         IF ((pctsrf(i,is_oce).GT.epsfra) .OR.
     .       (pctsrf(i,is_sic).GT.epsfra)) THEN
c fabriquer de la glace si congelation atteinte:
         IF (tslab(i).LT.(RTT-1.8)) THEN
            zz =  (RTT-1.8)-tslab(i)
            seaice(i) = seaice(i) + cyang/cbing * zz
            tslab(i) = RTT-1.8
         ENDIF
c faire fondre de la glace si temperature est superieure a 0:
         IF ((tslab(i).GT.RTT) .AND. (seaice(i).GT.0.0)) THEN
            zz = cyang/cbing * (tslab(i)-RTT)
            zz = MIN(zz,seaice(i))
            seaice(i) = seaice(i) - zz
            tslab(i) = tslab(i) - zz*cbing/cyang
         ENDIF
c determiner la nature du sol (glace de mer ou ocean libre):
         IF (seaice(i).GT.45.0) THEN ! seuil fixe a 45 kg/m2
            pctsrf(i,is_oce) = 0.0
            pctsrf(i,is_sic) = 1.0
         ELSE
            pctsrf(i,is_oce) = 1.0
            pctsrf(i,is_sic) = 0.0
         ENDIF
c limiter la glace de mer a 10 metres (10000 kg/m2)
         seaice(i) = MIN(seaice(i),10000.0)
c donner la temperature de slab pour la variable de SST
         ftsol(i,is_oce) = tslab(i)
         ENDIF
         ENDDO
c
      ELSE ! .not.ok_slab
         DO i = 1, klon
            ftsol(i,is_oce) = lmt_sst(i)
         ENDDO
      ENDIF ! end of test ok_slab
c
      IF (check) THEN
         za=qcheck(klon,klev,paprs,q_seri,ql_seri,paire)
         zb=cptcheck(klon,klev,paprs,t_seri,paire)
         PRINT*, "avanreeva=", za, zb
      ENDIF
c
c Re-evaporer l'eau liquide nuageuse
c
      DO k = 1, klev  ! re-evaporation de l'eau liquide nuageuse
      DO i = 1, klon
         d_t_eva(i,k) = 0.0
         d_q_eva(i,k) = 0.0
c
         zlvdcp=RLVTT/RCPD/(1.0+RVTMP2*q_seri(i,k))
         zlsdcp=RLSTT/RCPD/(1.0+RVTMP2*q_seri(i,k))
         zdelta = MAX(0.,SIGN(1.,RTT-t_seri(i,k)))
         zb = MAX(0.0,ql_seri(i,k))
         za = - MAX(0.0,ql_seri(i,k))
     .                  * (zlvdcp*(1.-zdelta)+zlsdcp*zdelta)
         t_seri(i,k) = t_seri(i,k) + za
         q_seri(i,k) = q_seri(i,k) + zb
         ql_seri(i,k) = 0.0
         d_t_eva(i,k) = za
         d_q_eva(i,k) = zb
      ENDDO
      ENDDO
c
c Appeler la diffusion verticale (programme de couche limite)
c
      DO i = 1, klon
         frugs(i,is_ter) = SQRT(lmt_rug(i)**2+rugoro(i)**2)
         frugs(i,is_lic) = rugoro(i)
         frugs(i,is_oce) = rugmer(i)
         frugs(i,is_sic) = 0.001
         zxrugs(i) = 0.0
      ENDDO
      DO nsrf = 1, nbsrf
      DO i = 1, klon
         frugs(i,nsrf) = MAX(frugs(i,nsrf),0.001)
      ENDDO
      ENDDO
      DO nsrf = 1, nbsrf
      DO i = 1, klon
         zxrugs(i) = zxrugs(i) + frugs(i,nsrf)*pctsrf(i,nsrf)
      ENDDO
      ENDDO
c
      IF (nqmax.GT.2) THEN
      DO iq=1, nqmax-2
        DO i=1, klon
          source_tr(i,iq) = 0.0 ! pas de source, pour l'instant
        ENDDO
        DO k=1, klev
          taupuits(k,iq) = 3.*86400.
        ENDDO
      ENDDO
      ENDIF !--nqmax GT 2
      IF (check) THEN
         za=qcheck(klon,klev,paprs,q_seri,ql_seri,paire)
         zb=cptcheck(klon,klev,paprs,t_seri,paire)
         PRINT*, "avanclmain=", za, zb
      ENDIF
c
      IF (soil_model) THEN ! appeler le modele du sol
         CALL soil(1,dtime,pctsrf,fsnow,ftsol,ftsoil, 
     .             soilcap,soilflux)
      ENDIF
c
      CALL clmain(dtime,pctsrf,
     e            t_seri,q_seri,u_seri,v_seri,
     e            soil_model,
     e            ftsol,soilcap,soilflux,paprs,pplay,radsol,
     e            fsnow,fqsol,
     e            rlat, frugs,
     s            d_t_vdf,d_q_vdf,d_u_vdf,d_v_vdf,d_ts,
     s            fluxt,fluxq,fluxu,fluxv,cdragh,cdragm,rugmer,
     s            dsens, devap, fluxg, fluxo,
     .            nqmax-2,tr_seri,source_tr,d_tr)
c
      IF (nqmax.GT.2) THEN
      DO iq=1, nqmax-2
      DO k = 1, klev
      DO i = 1, klon
         tr_seri(i,k,iq) = tr_seri(i,k,iq) + d_tr(i,k,iq)
         tr_seri(i,k,iq) = tr_seri(i,k,iq) * (1.-dtime/taupuits(k,iq))
      ENDDO
      ENDDO
      WRITE(iqn,'(i2.2)') iq
      CALL minmaxqfi(tr_seri(1,1,iq),0.,1.e33,'couche lim iq='//iqn)
      ENDDO
      ENDIF
c
      DO i = 1, klon
         sens(i) = - fluxt(i,1) ! flux de chaleur sensible au sol
         evap(i) = - fluxq(i,1) ! flux d'evaporation au sol
         fder(i) = dsens(i) + devap(i)
      ENDDO
      DO k = 1, klev
      DO i = 1, klon
         t_seri(i,k) = t_seri(i,k) + d_t_vdf(i,k)
         q_seri(i,k) = q_seri(i,k) + d_q_vdf(i,k)
         u_seri(i,k) = u_seri(i,k) + d_u_vdf(i,k)
         v_seri(i,k) = v_seri(i,k) + d_v_vdf(i,k)
      ENDDO
      ENDDO
c
c Incrementer la temperature du sol
c
      DO nsrf = 1, nbsrf
      DO i = 1, klon
      IF (pctsrf(i,nsrf).GT.epsfra) THEN
         ftsol(i,nsrf) = ftsol(i,nsrf) + d_ts(i,nsrf)
      ENDIF
      ENDDO
      ENDDO
c
      IF (soil_model) THEN ! appeler de nouveau le modele du sol
         CALL soil(2,dtime,pctsrf,fsnow,ftsol,ftsoil,
     .             soilcap,soilflux)
      ENDIF
c
      DO i = 1, klon
         zxtsol(i) = 0.0
      ENDDO
      DO nsrf = 1, nbsrf
      DO i = 1, klon
         zxtsol(i) = zxtsol(i) + ftsol(i,nsrf)*pctsrf(i,nsrf)
      ENDDO
      ENDDO
c
      IF (check) THEN
         za=qcheck(klon,klev,paprs,q_seri,ql_seri,paire)
         zb=cptcheck(klon,klev,paprs,t_seri,paire)
         PRINT*, "apreclmain=", za, zb
         zx_t = 0.0
         za = 0.0
         DO i = 1, klon
            za = za + paire(i)/FLOAT(klon)
            zx_t = zx_t + evap(i)*paire(i)/FLOAT(klon)
         ENDDO
         zx_t = zx_t/za*dtime
         PRINT*, "Evap=", zx_t
         zx_t = 0.0
         DO i = 1, klon
            zx_t = zx_t + (evap(i)*RLVTT+sens(i))*paire(i)/FLOAT(klon)
         ENDDO
         zx_t = zx_t/za*dtime
         PRINT*, "Flux chaleur=", zx_t
      ENDIF
c
c Calculer la derive du flux infrarouge
c
      DO nsrf = 1, nbsrf
      DO i = 1, klon
         fder(i) = fder(i) - 4.0*RSIGMA*zxtsol(i)**3 *
     .                       (ftsol(i,nsrf)-zxtsol(i))
     .                      *pctsrf(i,nsrf)
      ENDDO
      ENDDO
c
c Appeler la convection (au choix)
c
      IF (iflag_con.EQ.1) THEN
      DO k = 1, klev
      DO i = 1, klon
         conv_q(i,k) = d_q_dyn(i,k) + d_q_vdf(i,k)/dtime
         conv_t(i,k) = d_t_dyn(i,k) + d_t_vdf(i,k)/dtime
      ENDDO
      ENDDO
      ENDIF
      IF (iflag_con.EQ.2) THEN
      DO k = 1, klev
      DO i = 1, klon
         conv_q(i,k) = d_q_dyn(i,k) + d_q_vdf(i,k)/dtime
         conv_t(i,k) = d_t_dyn(i,k) + d_t_vdf(i,k)/dtime
      ENDDO
      ENDDO
      ENDIF
      IF (check) THEN
         za = qcheck(klon,klev,paprs,q_seri,ql_seri,paire)
         zb = cptcheck(klon,klev,paprs,t_seri,paire)
         PRINT*, "avantcon=", za, zb
      ENDIF
      zx_ajustq = .FALSE.
      IF (iflag_con.EQ.2) zx_ajustq=.TRUE.
      IF (zx_ajustq) THEN
         DO i = 1, klon
            z_avant(i) = 0.0
         ENDDO
         DO k = 1, klev
         DO i = 1, klon
            z_avant(i) = z_avant(i) + (q_seri(i,k)+ql_seri(i,k))
     .                        *(paprs(i,k)-paprs(i,k+1))/RG
         ENDDO
         ENDDO
      ENDIF
      IF (iflag_con.EQ.1) THEN
      CALL conlmd (dtime, paprs, pplay, t_seri, q_seri, conv_q,
     .             d_t_con, d_q_con,
     .             rain_con, snow_con, ibas_con, itop_con)
      ELSE IF (iflag_con.EQ.2) THEN
      CALL conflx(dtime, paprs, pplay, t_seri, q_seri,
     e            conv_t, conv_q, fluxq(1,1), omega,
     s            d_t_con, d_q_con, rain_con, snow_con,
     s            pmfu, pmfd, pen_u, pde_u, pen_d, pde_d,
     s            kcbot, kctop, kdtop, pmflxr, pmflxs)
      DO i = 1, klon
         ibas_con(i) = klev+1 - kcbot(i)
         itop_con(i) = klev+1 - kctop(i)
      ENDDO
      ELSE IF (iflag_con.EQ.3) THEN
      CALL conccm (dtime,paprs,pplay,t_seri,q_seri,conv_q,
     s             d_t_con, d_q_con, 
     s             rain_con, snow_con, ibas_con, itop_con)
      ELSE
      PRINT*, "iflag_con non-prevu", iflag_con
      CALL abort
      ENDIF
      CALL homogene(paprs, q_seri, d_q_con, u_seri,v_seri,
     .              d_u_con, d_v_con, frachomo)
ccc      CALL homogene2(paprs, rain_con,snow_con,ibas_con,itop_con,
ccc     .               u_seri,v_seri, d_u_con, d_v_con, frachomo)
      DO k = 1, klev
      DO i = 1, klon
         t_seri(i,k) = t_seri(i,k) + d_t_con(i,k)
         q_seri(i,k) = q_seri(i,k) + d_q_con(i,k)
         u_seri(i,k) = u_seri(i,k) + d_u_con(i,k)
         v_seri(i,k) = v_seri(i,k) + d_v_con(i,k)
      ENDDO
      ENDDO
      IF (check) THEN
         za = qcheck(klon,klev,paprs,q_seri,ql_seri,paire)
         zb = cptcheck(klon,klev,paprs,t_seri,paire)
         PRINT*, "aprescon=", za, zb
         zx_t = 0.0
         za = 0.0
         DO i = 1, klon
            za = za + paire(i)/FLOAT(klon)
            zx_t = zx_t + (rain_con(i)+snow_con(i))*paire(i)/FLOAT(klon)
         ENDDO
         zx_t = zx_t/za*dtime
         PRINT*, "Precip=", zx_t, zx_t*RLVTT
      ENDIF
      IF (zx_ajustq) THEN
         DO i = 1, klon
            z_apres(i) = 0.0
         ENDDO
         DO k = 1, klev
         DO i = 1, klon
            z_apres(i) = z_apres(i) + (q_seri(i,k)+ql_seri(i,k))
     .                        *(paprs(i,k)-paprs(i,k+1))/RG
         ENDDO
         ENDDO
         DO i = 1, klon
         z_factor(i) = (z_avant(i)-(rain_con(i)+snow_con(i))*dtime)
     .                /z_apres(i)
         ENDDO
ccc         DO k = 1, klev
ccc         DO i = 1, klon
ccc         IF (z_factor(i).GT.(1.0+1.0E-08) .OR.
ccc     .       z_factor(i).LT.(1.0-1.0E-08)) THEN
ccc               q_seri(i,k) = q_seri(i,k) * z_factor(i)
ccc         ENDIF
ccc         ENDDO
ccc         ENDDO
         DO i = 1, klon
         IF (z_factor(i).GT.(1.0+1.0E-08) .OR. 
     .       z_factor(i).LT.(1.0-1.0E-08)) THEN
               rain_con(i) = rain_con(i) * z_factor(i)
         ENDIF
         ENDDO
      ENDIF
      zx_ajustq=.FALSE.
c
      IF (nqmax.GT.2) THEN !--melange convectif de traceurs
c
      IF (iflag_con.NE.2) THEN
         PRINT*, "Pour l instant, seul conflx fonctionne avec traceurs"
         PRINT*,' Mettre iflag_con = 2  dans  run.def et repasser  !'
         CALL abort
      ENDIF
c
      DO iq=1, nqmax-2
      CALL flxtr(dtime, pmfu, pmfd, pen_u, pde_u, pen_d, pde_d,
     .            t_seri, pplay, paprs, kcbot, kctop, kdtop,
     .            tr_seri(1,1,iq), d_tr(1,1,iq) )
      DO k = 1, klev
      DO i = 1, klon
         tr_seri(i,k,iq) = tr_seri(i,k,iq) + d_tr(i,k,iq)
      ENDDO
      ENDDO
      WRITE(iqn,'(i2.2)') iq
      CALL minmaxqfi(tr_seri(1,1,iq),0.,1.e33,'convection iq='//iqn)
      ENDDO
c
      ENDIF !--nqmax.GT.2
c
c Appeler l'ajustement sec
c
      IF (check) THEN
         za = qcheck(klon,klev,paprs,q_seri,ql_seri,paire)
         zb = cptcheck(klon,klev,paprs,t_seri,paire)
         PRINT*, "avantsec=", za, zb
      ENDIF
      CALL ajsec(paprs, pplay, t_seri, q_seri, d_t_ajs, d_q_ajs,
     .           nqmax-2, tr_seri, d_tr)
      IF (nqmax.GT.2) THEN
      DO iq=1, nqmax-2
      DO k = 1, klev
      DO i = 1, klon
         tr_seri(i,k,iq) = tr_seri(i,k,iq) + d_tr(i,k,iq)
      ENDDO
      ENDDO
      WRITE(iqn,'(i2.2)') iq
      CALL minmaxqfi(tr_seri(1,1,iq),0.,1.e33,'ajsec iq='//iqn)
      ENDDO
      ENDIF !--nqmax
c
      DO k = 1, klev
      DO i = 1, klon
         t_seri(i,k) = t_seri(i,k) + d_t_ajs(i,k)
         q_seri(i,k) = q_seri(i,k) + d_q_ajs(i,k)
      ENDDO
      ENDDO
      IF (check) THEN
         za = qcheck(klon,klev,paprs,q_seri,ql_seri,paire)
         zb = cptcheck(klon,klev,paprs,t_seri,paire)
         PRINT*, "apresec=", za, zb
      ENDIF
c
c Appeler le processus de condensation a grande echelle
c et le processus de precipitation
c
      CALL fisrtilp(dtime,paprs,pplay,
     .           t_seri, q_seri,
     .           d_t_lsc, d_q_lsc, d_ql_lsc, rneb, cldliq,
     .           rain_lsc, snow_lsc)
      DO k = 1, klev
      DO i = 1, klon
         t_seri(i,k) = t_seri(i,k) + d_t_lsc(i,k)
         q_seri(i,k) = q_seri(i,k) + d_q_lsc(i,k)
         ql_seri(i,k) = ql_seri(i,k) + d_ql_lsc(i,k)
         cldfra(i,k) = rneb(i,k)
         IF (.NOT.new_oliq) cldliq(i,k) = ql_seri(i,k)
      ENDDO
      ENDDO
      IF (check) THEN
         za = qcheck(klon,klev,paprs,q_seri,ql_seri,paire)
         zb = cptcheck(klon,klev,paprs,t_seri,paire)
         PRINT*, "apresilp=", za, zb
         zx_t = 0.0
         za = 0.0
         DO i = 1, klon
            za = za + paire(i)/FLOAT(klon)
            zx_t = zx_t + (rain_lsc(i)+snow_lsc(i))*paire(i)/FLOAT(klon)
         ENDDO
         zx_t = zx_t/za*dtime
         PRINT*, "Precip=", zx_t, zx_t*RLVTT
      ENDIF
c
c Nuages diagnostiques:
c
      IF (iflag_con.EQ.2) THEN ! seulement pour Tiedtke
      CALL diagcld1(paprs,pplay,
     .             rain_con,snow_con,ibas_con,itop_con,
     .             diafra,dialiq)
      DO k = 1, klev
      DO i = 1, klon
      IF (diafra(i,k).GT.cldfra(i,k)) THEN
         cldliq(i,k) = dialiq(i,k)
         cldfra(i,k) = diafra(i,k)
      ENDIF
      ENDDO
      ENDDO
      ENDIF
c
c Nuages stratus artificiels:
c
      IF (ok_stratus) THEN
      CALL diagcld2(paprs,pplay,t_seri,q_seri, diafra,dialiq)
      DO k = 1, klev
      DO i = 1, klon
      IF (diafra(i,k).GT.cldfra(i,k)) THEN
         cldliq(i,k) = dialiq(i,k)
         cldfra(i,k) = diafra(i,k)
      ENDIF
      ENDDO
      ENDDO
      ENDIF
c
c Precipitation totale
c
      DO i = 1, klon
         rain_fall(i) = rain_con(i) + rain_lsc(i)
         snow_fall(i) = snow_con(i) + snow_lsc(i)
      ENDDO
c
c Calculer l'humidite relative pour diagnostique
c
      DO k = 1, klev
      DO i = 1, klon
         zx_t = t_seri(i,k)
         IF (thermcep) THEN
            zdelta = MAX(0.,SIGN(1.,rtt-zx_t))
            zx_qs  = r2es * FOEEW(zx_t,zdelta)/pplay(i,k)
            zx_qs  = MIN(0.5,zx_qs)
            zcor   = 1./(1.-retv*zx_qs)
            zx_qs  = zx_qs*zcor
         ELSE
           IF (zx_t.LT.t_coup) THEN
              zx_qs = qsats(zx_t)/pplay(i,k)
           ELSE
              zx_qs = qsatl(zx_t)/pplay(i,k)
           ENDIF
         ENDIF
         zx_rh(i,k) = q_seri(i,k)/zx_qs
      ENDDO
      ENDDO
c
c Calculer les parametres optiques des nuages et quelques
c parametres pour diagnostiques:
c
c perturb
c Ajouter une perturbation dans les nuages pour le rayonnement
c      DO k = 1, klev
c      DO i = 1, klon
c erreur         cldliq(i,k) = cldliq(i,k) *(1.0-ran())/2.5
c erreur         cldliq(i,k) = cldliq(i,k) *(1.0-ran())/10.0
c          cldliq(i,k) = cldliq(i,k) * (1.0+(0.5-ran())/10.0) !5%
c          cldliq(i,k) = cldliq(i,k) * (1.0+(0.5-ran())/2.5) !20%
c      ENDDO
c      ENDDO
c perturb
      CALL nuage (paprs, pplay,
     .            t_seri, cldliq, cldfra, cldtau, cldemi,
     .            cldh, cldl, cldm, cldt, cldq)
c
c Appeler le rayonnement mais calculer tout d'abord l'albedo du sol.
c
      IF (MOD(itaprad,radpas).EQ.0) THEN
      CALL orbite(FLOAT(julien),zlongi,dist)
      IF (cycle_diurne) THEN
        zdtime=dtime*FLOAT(radpas) ! pas de temps du rayonnement (s)
        CALL zenang(zlongi,gmtime,zdtime,rlat,rlon,rmu0,fract)
c        CALL zenith(zlongi,gmtime,rlat,rlon,rmu0,fract) !va disparaitre
        CALL alboc_cd(rmu0,alb_eau)
      ELSE
        CALL angle(zlongi,rlat,fract,rmu0)
        CALL alboc(FLOAT(julien),rlat,alb_eau)
      ENDIF
      CALL albsno(veget,agesno,alb_neig)
      DO i = 1, klon
         zx_alb_oce = alb_eau(i)
         IF (pctsrf(i,is_oce).GT.epsfra .AND. ftsol(i,is_oce).LT.271.35)
     .   zx_alb_oce = 0.6 ! pour slab_ocean
         zfra = MAX(0.0,MIN(1.0,fsnow(i,is_lic)/(fsnow(i,is_lic)+10.0)))
         zx_alb_lic = alb_neig(i)*zfra + 0.6*(1.0-zfra)
         zfra = MAX(0.0,MIN(1.0,fsnow(i,is_ter)/(fsnow(i,is_ter)+10.0)))
         zx_alb_ter = alb_neig(i)*zfra + lmt_alb(i)*(1.0-zfra)
         zfra = MAX(0.0,MIN(1.0,fsnow(i,is_sic)/(fsnow(i,is_sic)+10.0)))
         zx_alb_sic = alb_neig(i)*zfra + 0.6*(1.0-zfra)
         albsol(i) = zx_alb_oce * pctsrf(i,is_oce)
     .             + zx_alb_lic * pctsrf(i,is_lic)
     .             + zx_alb_ter * pctsrf(i,is_ter)
     .             + zx_alb_sic * pctsrf(i,is_sic)
      ENDDO
      CALL radlwsw ! nouveau rayonnement (compatible Arpege-IFS)
     e            (dist, rmu0, fract, rlat,co2_ppm,co2_bis, solaire,
     e             paprs, pplay,zxtsol,albsol, t_seri,q_seri,wo,
     e             cldfra, cldemi, cldtau,
     s             heat,heat0,cool,cool0,radsol,albpla,
     s             topsw,toplw,topsw0,toplw0,
     s             solsw_up, solsw_dn,sollw_up,sollw_dn)
      itaprad = 0
      ENDIF
      itaprad = itaprad + 1
c
c Ajouter la tendance des rayonnements (tous les pas)
c
      DO k = 1, klev
      DO i = 1, klon
         t_seri(i,k) = t_seri(i,k)
     .               + (heat(i,k)-cool(i,k)) * dtime/86400.
      ENDDO
      ENDDO
c
c Calculer l'hydrologie de la surface
c
      CALL hydrol(dtime,pctsrf,ok_slab,seaice,
     .            rain_fall, snow_fall, evap,
     .            agesno, ftsol,fqsol,fsnow, ruis)
c
      DO i = 1, klon
         zxqsol(i) = 0.0
         zxsnow(i) = 0.0
      ENDDO
      DO nsrf = 1, nbsrf
      DO i = 1, klon
         zxqsol(i) = zxqsol(i) + fqsol(i,nsrf)*pctsrf(i,nsrf)
         zxsnow(i) = zxsnow(i) + fsnow(i,nsrf)*pctsrf(i,nsrf)
      ENDDO
      ENDDO
c
c Si une sous-fraction n'existe pas, elle prend la valeur moyenne
c
      DO nsrf = 1, nbsrf
      DO i = 1, klon
         IF (pctsrf(i,nsrf).LT.epsfra) THEN
            fqsol(i,nsrf) = zxqsol(i)
            fsnow(i,nsrf) = zxsnow(i)
         ENDIF
      ENDDO
      ENDDO
c
c Calculer le bilan du sol et la derive de temperature (couplage)
c
      DO i = 1, klon
         bils(i) = radsol(i) - sens(i) - evap(i)*RLVTT
      ENDDO
c
c Calculer le bilan du flux:
c
      IF (ok_slab) THEN
      DO i = 1, klon
      IF (pctsrf(i,is_oce).GT.epsfra .OR.
     .    pctsrf(i,is_sic).GT.epsfra) THEN
         za = radsol(i) + fluxo(i)
         zb = radsol(i) + fluxg(i)
c old flux         za = bils(i) ! To be changed to open ocean's value later
c old flux         zb = (ftsol(i,is_sic)-(273.15-1.8))
c old flux     .      * (5.1444E+06*0.15) / (30.0*86400.0)
         slab_bils(i) = slab_bils(i) + (za*pctsrf(i,is_oce)
     .                                 +zb*pctsrf(i,is_sic))
     .                                 / FLOAT(slab_pas)
      ENDIF
      ENDDO
      ENDIF
c
      IF (ok_slab .AND. (MOD(itap,slab_pas).EQ.0)) THEN
      DO i = 1, klon
      IF (pctsrf(i,is_oce).GT.epsfra .OR.
     .    pctsrf(i,is_sic).GT.epsfra) THEN
         tslab(i) = tslab(i) + (slab_bils(i)-lmt_bils(i))
     .                         /cyang*dtime*FLOAT(slab_pas)
         slab_bils(i) = 0.0 ! remettre l'accumulation a zero
      ENDIF
      ENDDO
      ENDIF
c
cmoddeblott(jan95)
c Appeler le programme de parametrisation de l'orographie
c a l'echelle sous-maille:
c
      IF (ok_orodr) THEN
c
c  selection des points pour lesquels le shema est actif:
        igwd=0
        DO i=1,klon
        itest(i)=0
c        IF ((zstd(i).gt.10.0)) THEN
        IF (((zpic(i)-zmea(i)).GT.100.).AND.(zstd(i).GT.10.0)) THEN
          itest(i)=1
          igwd=igwd+1
          idx(igwd)=i
        ENDIF
        ENDDO
        igwdim=MAX(1,igwd)
c
        CALL drag_noro(klon,klev,dtime,paprs,pplay,
     e                   zmea,zstd, zsig, zgam, zthe,zpic,zval,
     e                   igwd,igwdim,idx,itest,
     e                   t_seri, u_seri, v_seri,
     s                   zulow, zvlow, zustr, zvstr,
     s                   d_t_oro, d_u_oro, d_v_oro)
c
c  ajout des tendances
        DO k = 1, klev
        DO i = 1, klon
           t_seri(i,k) = t_seri(i,k) + d_t_oro(i,k)
           u_seri(i,k) = u_seri(i,k) + d_u_oro(i,k)
           v_seri(i,k) = v_seri(i,k) + d_v_oro(i,k)
        ENDDO
        ENDDO
c
      ENDIF ! fin de test sur ok_orodr
c
      IF (ok_orolf) THEN
c
c  selection des points pour lesquels le shema est actif:
        igwd=0
        DO i=1,klon
        itest(i)=0
        IF ((zpic(i)-zmea(i)).GT.100.) THEN
          itest(i)=1
          igwd=igwd+1
          idx(igwd)=i
        ENDIF
        ENDDO
        igwdim=MAX(1,igwd)
c
        CALL lift_noro(klon,klev,dtime,paprs,pplay,
     e                   rlat,zmea,zstd, zsig, zgam, zthe,zpic,zval,
     e                   igwd,igwdim,idx,itest,
     e                   t_seri, u_seri, v_seri,
     s                   zulow, zvlow, zustr, zvstr,
     s                   d_t_lif, d_u_lif, d_v_lif)
c
c  ajout des tendances
        DO k = 1, klev
        DO i = 1, klon
           t_seri(i,k) = t_seri(i,k) + d_t_lif(i,k)
           u_seri(i,k) = u_seri(i,k) + d_u_lif(i,k)
           v_seri(i,k) = v_seri(i,k) + d_v_lif(i,k)
        ENDDO
        ENDDO
c
      ENDIF ! fin de test sur ok_orolf
c
c Calculer le transport de l'eau et de l'energie (diagnostique)
c
      CALL transp (paprs,zxtsol,
     e                   t_seri, q_seri, u_seri, v_seri, zphi,
     s                   ve, vq, ue, uq)
c
c Accumuler les variables a stocker dans les fichiers histoire:
c
      IF (ok_oasis) THEN ! couplage oasis
      DO i = 1, klon
        oas_sols(i) = oas_sols(i) + (solsw_dn(i)-solsw_up(i))
     .                            / FLOAT(nexca)
        oas_nsol(i) = oas_nsol(i) + (bils(i)-solsw_dn(i)+solsw_up(i))
     .                            / FLOAT(nexca)
        oas_rain(i) = oas_rain(i) + rain_fall(i)      / FLOAT(nexca)
        oas_snow(i) = oas_snow(i) + snow_fall(i)      / FLOAT(nexca)
        oas_evap(i) = oas_evap(i) + evap(i)           / FLOAT(nexca)
        oas_tsol(i) = oas_tsol(i) + zxtsol(i)         / FLOAT(nexca)
        oas_fder(i) = oas_fder(i) + fder(i)           / FLOAT(nexca)
        oas_albe(i) = oas_albe(i) + albsol(i)         / FLOAT(nexca)
        oas_taux(i) = oas_taux(i) + fluxu(i,1)        / FLOAT(nexca)
        oas_tauy(i) = oas_tauy(i) + fluxv(i,1)        / FLOAT(nexca)
        oas_ruis(i) = oas_ruis(i) + ruis(i)       /FLOAT(nexca)/dtime
      ENDDO
      ENDIF
c
      CALL plevel(klon,klev,pplay,
     &     u_seri,v_seri,t_seri,zphi,qx(1,1,ivap),
     &     lstd,plvl,ulvl,vlvl,tlvl,glvl,qlvl,iwork1,iwork2)
c
c
c
      DO i = 1, klon
         zpr = paprs(i,1)-paprs(i,1)*9.81/287/zxtsol(i)*2.0
         t2m(i) = (t_seri(i,1)*(pplay(i,2)-zpr)
     .            -t_seri(i,2)*(pplay(i,1)-zpr))/
     .              (pplay(i,2)-pplay(i,1))
         q2m(i) = (qx(i,1,ivap)*(pplay(i,2)-zpr)
     .            -qx(i,2,ivap)*(pplay(i,1)-zpr))/
     .              (pplay(i,2)-pplay(i,1))
         zpr = paprs(i,1) - paprs(i,1)*9.81/287/zxtsol(i)*10.0
         u10m(i) = (u_seri(i,1)*(pplay(i,2)-zpr)
     .             -u_seri(i,2)*(pplay(i,1)-zpr))/
     .               (pplay(i,2)-pplay(i,1))
         v10m(i) = (v_seri(i,1)*(pplay(i,2)-zpr)
     .               -v_seri(i,2)*(pplay(i,1)-zpr))/
     .               (pplay(i,2)-pplay(i,1))
      ENDDO
c
      DO i = 1, klon
         slp(i) = paprs(i,1) *(1+0.0006*pphis(i)/t2m(i))
     .                         **(1.0/(0.0006*287.0))
      ENDDO
c
      IF (ok_journe) THEN
      CALL histday_surface("histday_surface",
     &     itap,ecritphy,dtime,pphis,paire,rlon,rlat,
     &     zxtsol,paprs(1,1),rain_fall,snow_fall,evap,topsw,
     &     toplw,solsw_up,solsw_dn,sollw_up,sollw_dn,bils,sens,
     &     fluxg,fluxo,fder,fluxu(1,1),fluxv(1,1),ruis,
     &     pctsrf(1,is_sic),cldl,cldm,cldh,cldt,cldq,
     &     slp,t2m,q2m,u10m,v10m,
     &     ok_slab,tslab,seaice)
ccc      CALL histday_modlevs("histday_modlevs",
ccc     &     itap,ecritphy,dtime,pphis,paire,rlon,rlat,presnivs,
ccc     &     paprs(1,1),
ccc     &     t_seri,qx(1,1,ivap),zphi,u_seri,v_seri,omega,pplay)
      CALL histday_stdlevs("histday_stdlevs",itap,ecritphy,dtime,
     &     lstd,tmp3d_std,ndex3d_std,
     &     pphis,paire,rlon,rlat,plvl,
     &     paprs(1,1),
     &     tlvl,qlvl,glvl,ulvl,vlvl)
      ENDIF
c
      IF (ok_instan) THEN
      CALL histins("histins",itap,0.25,dtime,lstd,tmp3d_std,ndex3d_std,
     &           pphis,paire,rlon,rlat,plvl,
     &           rain_fall,snow_fall,paprs(1,1),slp,t2m,q2m,u10m,v10m,
     &           tlvl,qlvl,glvl,ulvl,vlvl)
      ENDIF
c
      IF (ok_region) THEN
      CALL histreg("histreg",itap,0.25,dtime,
     &           10,27,3,13,
     &           lstd,tmp3d_std,ndex3d_std,
     &           pphis,paire,rlon,rlat,plvl,
     &           rain_fall,snow_fall,
     &           tlvl,qlvl,glvl,ulvl,vlvl)
      ENDIF
c
      IF (ok_mensuel) THEN
      CALL histmth("histmth",
     &     itap,1.0,dtime,pphis,paire,rlon,rlat,presnivs,
     &     zxtsol,paprs(1,1),rain_fall,snow_fall,evap,topsw,toplw,
     &     topsw0,toplw0,solsw_up,solsw_dn,sollw_up,sollw_dn,bils,sens,
     &     fluxg,fluxo,fder,fluxu(1,1),fluxv(1,1),ruis,
     &     pctsrf(1,is_sic),cldl,cldm,cldh,cldt,cldq,
     &     slp,t2m,q2m,u10m,v10m,
     &     t_seri,qx(1,1,ivap),zphi,u_seri,v_seri,omega,pplay,
     &     cldfra, cldliq, zx_rh,
     &     ok_slab,tslab,seaice)
      CALL histtnd("histtnd",
     &     itap,1.0,dtime,pphis,paire,rlon,rlat,presnivs,
     &     pplay,d_t_dyn,d_q_dyn,d_t_con,d_q_con,
     &     d_t_lsc,d_q_lsc,d_t_vdf,d_q_vdf,
     &     d_t_eva,d_q_eva,d_t_ajs,d_q_ajs,
     &     heat,heat0,cool,cool0)
      ENDIF
c
c
      IF (ok_oasis .AND. mod(itap,nexca).EQ.0) THEN
c
c Je ne traite pas le ruissellement, pour l'instant (qui m'aidera ?)
         DO i = 1, klon
            oas_ruisoce(i) = 0.0
            oas_ruisriv(i) = 0.0
         ENDDO
c
         ig = 1
         DO i = 1, iim
            z_sols(i,1) = oas_sols(ig)
            z_nsol(i,1) = oas_nsol(ig)
            z_rain(i,1) = oas_rain(ig)
            z_snow(i,1) = oas_snow(ig)
            z_evap(i,1) = oas_evap(ig)
            z_ruisoce(i,1) = oas_ruisoce(ig)
            z_ruisriv(i,1) = oas_ruisriv(ig)
            z_tsol(i,1) = oas_tsol(ig)
            z_fder(i,1) = oas_fder(ig)
            z_albe(i,1) = oas_albe(ig)
            z_taux(i,1) = oas_taux(ig)
            z_tauy(i,1) = oas_tauy(ig)
         ENDDO
         DO j = 2, jjm
         DO i = 1, iim
            ig = ig + 1
            z_sols(i,j) = oas_sols(ig)
            z_nsol(i,j) = oas_nsol(ig)
            z_rain(i,j) = oas_rain(ig)
            z_snow(i,j) = oas_snow(ig)
            z_evap(i,j) = oas_evap(ig)
            z_ruisoce(i,j) = oas_ruisoce(ig)
            z_ruisriv(i,j) = oas_ruisriv(ig)
            z_tsol(i,j) = oas_tsol(ig)
            z_fder(i,j) = oas_fder(ig)
            z_albe(i,j) = oas_albe(ig)
            z_taux(i,j) = oas_taux(ig)
            z_tauy(i,j) = oas_tauy(ig)
         ENDDO
         ENDDO
         ig = ig + 1
         DO i = 1, iim
            z_sols(i,jjm+1)    = oas_sols(ig)
            z_nsol(i,jjm+1)    = oas_nsol(ig)
            z_rain(i,jjm+1)    = oas_rain(ig)
            z_snow(i,jjm+1)    = oas_snow(ig)
            z_evap(i,jjm+1)    = oas_evap(ig)
            z_ruisoce(i,jjm+1) = oas_ruisoce(ig)
            z_ruisriv(i,jjm+1) = oas_ruisriv(ig)
            z_tsol(i,jjm+1)    = oas_tsol(ig)
            z_fder(i,jjm+1)    = oas_fder(ig)
            z_albe(i,jjm+1)    = oas_albe(ig)
            z_taux(i,jjm+1)    = oas_taux(ig)
            z_tauy(i,jjm+1)    = oas_tauy(ig)
         ENDDO
c
c je soupconne que les vents des 2 poles ne sont pas corrects:
c je fais donc un bricolage ci-apres:
c
ccc         z_taux(1,1) = 0.0
ccc         z_tauy(1,1) = 0.0
ccc         DO i = 1, iim
ccc            z_taux(1,1) = z_taux(1,1) + z_taux(i,2)/FLOAT(iim)
ccc            z_tauy(1,1) = z_tauy(1,1) + z_tauy(i,2)/FLOAT(iim)
ccc         ENDDO
ccc         DO i = 2, iim
ccc            z_taux(i,1) = z_taux(1,1)
ccc            z_tauy(i,1) = z_tauy(1,1)
ccc         ENDDO
cccc
ccc         z_taux(1,jjm+1) = 0.0
ccc         z_tauy(1,jjm+1) = 0.0
ccc         DO i = 1, iim
ccc            z_taux(1,jjm+1) = z_taux(1,jjm+1) + z_taux(i,jjm)/FLOAT(iim)
ccc            z_tauy(1,jjm+1) = z_tauy(1,jjm+1) + z_tauy(i,jjm)/FLOAT(iim)
ccc         ENDDO
ccc         DO i = 2, iim
ccc            z_taux(i,jjm+1) = z_taux(1,jjm+1)
ccc            z_tauy(i,jjm+1) = z_tauy(1,jjm+1)
ccc         ENDDO
c
         DO j = 1, jjm+1
         DO i = 1, iim
            z_watf(i,j) = z_rain(i,j) + z_snow(i,j) - z_evap(i,j)
         ENDDO
         ENDDO
c
c Passer les champs au coupleur:
c
         CALL intocpl(itap,(jjm+1)*iim,
     .                   z_sols, z_nsol,
     .                   z_rain, z_snow, z_evap, z_watf,
     .                   z_ruisoce, z_ruisriv,
     .                   z_tsol, z_fder, z_albe,
     .                   z_taux, z_tauy, lafin)
         DO i = 1, klon
           oas_sols(i) = 0.0
           oas_nsol(i) = 0.0
           oas_rain(i) = 0.0
           oas_snow(i) = 0.0
           oas_evap(i) = 0.0
           oas_ruis(i) = 0.0
           oas_tsol(i) = 0.0
           oas_fder(i) = 0.0
           oas_albe(i) = 0.0
           oas_taux(i) = 0.0
           oas_tauy(i) = 0.0
         ENDDO
      ENDIF
c
c Convertir les incrementations en tendances
c
      DO k = 1, klev
      DO i = 1, klon
         d_u(i,k) = ( u_seri(i,k) - u(i,k) ) / dtime
         d_v(i,k) = ( v_seri(i,k) - v(i,k) ) / dtime
         d_t(i,k) = ( t_seri(i,k)-t(i,k) ) / dtime
         d_qx(i,k,ivap) = ( q_seri(i,k) - qx(i,k,ivap) ) / dtime
         d_qx(i,k,iliq) = ( ql_seri(i,k) - qx(i,k,iliq) ) / dtime
      ENDDO
      ENDDO
c
      IF (nqmax.GE.3) THEN
      DO iq = 3, nqmax
      DO  k = 1, klev
      DO  i = 1, klon
         d_qx(i,k,iq) = ( tr_seri(i,k,iq-2) - qx(i,k,iq) ) / dtime
      ENDDO
      ENDDO
      ENDDO
      ENDIF
c
c Sauvegarder les valeurs de t et q a la fin de la physique:
c
      DO k = 1, klev
      DO i = 1, klon
         t_ancien(i,k) = t_seri(i,k)
         q_ancien(i,k) = q_seri(i,k)
      ENDDO
      ENDDO
c
c Si c'est la fin, il faut conserver l'etat de redemarrage
c
      IF (lafin) THEN
c
ccc         IF (ok_oasis) CALL quitcpl
c
         CALL phyredem ("restartphy.nc",dtime,radpas,co2_ppm,solaire,
     .        rlat,rlon,ftsol,ftsoil,tslab,seaice,fqsol,fsnow,
     .        radsol,rugmer,agesno,
     .        zmea,zstd,zsig,zgam,zthe,zpic,zval,rugoro,
     .        t_ancien, q_ancien)
c
         CALL histclo
c
      ENDIF
c
      RETURN
      END
      FUNCTION qcheck(klon,klev,paprs,q,ql,aire)
      IMPLICIT none
c
c Calculer et imprimer l'eau totale. A utiliser pour verifier
c la conservation de l'eau
c
#include "YOMCST.h"
      INTEGER klon,klev
      REAL paprs(klon,klev+1), q(klon,klev), ql(klon,klev)
      REAL aire(klon)
      REAL qtotal, zx, qcheck
      INTEGER i, k
c
      zx = 0.0
      DO i = 1, klon
         zx = zx + aire(i)
      ENDDO
      qtotal = 0.0
      DO k = 1, klev
      DO i = 1, klon
         qtotal = qtotal + (q(i,k)+ql(i,k)) * aire(i)
     .                     *(paprs(i,k)-paprs(i,k+1))/RG
      ENDDO
      ENDDO
c
      qcheck = qtotal/zx
c
      RETURN
      END
      FUNCTION cptcheck(klon,klev,paprs,t,aire)
      IMPLICIT none
c
c Calculer et imprimer l'eau totale. A utiliser pour verifier
c la conservation de l'eau
c
#include "YOMCST.h"
      INTEGER klon,klev
      REAL paprs(klon,klev+1), t(klon,klev)
      REAL aire(klon)
      REAL cpttotal, zx, cptcheck
      INTEGER i, k
c
      zx = 0.0
      DO i = 1, klon
         zx = zx + aire(i)
      ENDDO
      cpttotal = 0.0
      DO k = 1, klev
      DO i = 1, klon
         cpttotal = cpttotal + RCPD*t(i,k) * aire(i)
     .                     *(paprs(i,k)-paprs(i,k+1))/RG
      ENDDO
      ENDDO
c
      cptcheck = cpttotal/zx
c
      RETURN
      END
c perturb
c      REAL FUNCTION ran()
c      INTEGER im, ia, ic
c      PARAMETER (im=6075,ia=106,ic=1283)
c      INTEGER jran
c      SAVE jran
c      DATA jran/1/
c      DO i = 1, 20
c      jran=mod(jran*ia+ic,im)
c      ran=float(jran)/float(im)
c      ENDDO
c      RETURN
c      END
c perturb
      SUBROUTINE plevel(klon,klev,pls,u,v,t,g,q,
     .                  llm,plvl,ulvl,vlvl,tlvl,glvl,qlvl,lt,lb)
      IMPLICIT none
c
      INTEGER klon, klev, llm 
      REAL u(klon,klev), v(klon,klev), t(klon,klev)
      REAL pls(klon,klev)
      REAL g(klon,klev), q(klon,klev)
c
      REAL plvl(llm)
      REAL ulvl(klon,llm), vlvl(klon,llm), tlvl(klon,llm)
      REAL glvl(klon,llm), qlvl(klon,llm)
      INTEGER lt(klon), lb(klon)
c
      REAL ptop, pbot, aist, aisb
      INTEGER i, k, l
c
      DO 99999 l = 1, llm
c
c Chercher les 2 couches les plus proches du niveau a obtenir
c
c Eventuellement, faire l'extrapolation a partir des deux couches
c les plus basses ou les deux couches les plus hautes:
      DO 130 i = 1, klon
         IF ( ABS((100.*plvl(l))-pls(i,klev) ) .LT.
     .        ABS((100.*plvl(l))-pls(i,1)) ) THEN
            lt(i) = klev     ! 2
            lb(i) = klev-1   ! 1
         ELSE
            lt(i) = 2
            lb(i) = 1
         ENDIF
  130 CONTINUE
      DO 150 k = 1, klev-1
         DO 140 i = 1, klon
            pbot = pls(i,k)
            ptop = pls(i,k+1)
            IF (ptop.LE.(100.*plvl(l)) .AND. 
     .          pbot.GE.(100.*plvl(l))) THEN
               lt(i) = k+1
               lb(i) = k
            ENDIF
  140    CONTINUE
  150 CONTINUE
c
      DO 160 i = 1, klon
c interpolation en logarithme de pression:
c
        aist = LOG( pls(i,lb(i))/ (100.0*plvl(l)) )
     .       / LOG( pls(i,lb(i))/ pls(i,lt(i)) )
        aisb = LOG( (100.0*plvl(l)) / pls(i,lt(i)) )
     .       / LOG( pls(i,lb(i))/ pls(i,lt(i)))
        ulvl(i,l) = u(i,lb(i)) * aisb + u(i,lt(i)) * aist
        vlvl(i,l) = v(i,lb(i)) * aisb + v(i,lt(i)) * aist
        tlvl(i,l) = t(i,lb(i)) * aisb + t(i,lt(i)) * aist
        glvl(i,l) = g(i,lb(i)) * aisb + g(i,lt(i)) * aist
        qlvl(i,l) = q(i,lb(i)) * aisb + q(i,lt(i)) * aist
  160 CONTINUE
c
c Je mets les vents a zero quand je rencontre une montagne
ccc      DO i = 1, klon
ccc      IF (pls(i,1).LT.(100.0*plvl(l))) THEN
ccc         ulvl(i,l) = 0.0
ccc         vlvl(i,l) = 0.0
ccc      ENDIF
ccc      ENDDO
c
99999 CONTINUE
c
      RETURN
      END
